function [ef_dcs_x ef_dcs_z] = ecurrent_offset(orb_data, ef_data, sa_data)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
% Co-Author: Steven Chen
%
% This function calculates and then subtracts the electric current offset 
% from the electric field data for the X and Z components (DCS2). 
%
% Inputs:
% orb_data - orbital data
% ef_data - electric field data
% sa_data - spin axis data
%
% Outputs:
% ef_dcs_x - the electric field X componenet (DCS2) with the electric
% current offset removed
% ef_dcs_z - the electric field Z componenet (DCS2) with the electric
% current offest removed
%
% Expected format of input matrices:
% ef_matrix(:,1)        = unix time
% ef_matrix(:,2)        = e-field x (DCS2) (along V)
% ef_matrix(:,3)        = e-field y 
% ef_matrix(:,4)        = e-field z (DCS2) (near B)
%
% orb_data(:,1)       = unix time
% orb_data(:,2:4)     = pos x,y,z (gei)
% orb_data(:,5:7)     = vel x,y,z (gei)
% orb_data(:,8:10)    = pos x,y,z (geo)
% orb_data(:,11:13)   = vel x,y,z (geo)
% orb_data(:,14:16)   = altitude, latitude, longitude
% orb_data(:,17:19)   = b-model x,y,z (gei)
% orb_data(:,20:22)   = b-model x,y,z (geo)
% orb_data(:,23)      = ilat
% orb_data(:,24)      = mlt
% orb_data(:,25:27)   = BFOOT
%
% sa_matrix(:,1) = unix time
% sa_matrix(:,2) = right ascention angle
% sa_matrix(:,3) = declination angle
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    orb_matrix = [orb_data(:,1), orb_data(:,11:13), orb_data(:,20:22), orb_data(:,14)];
    % orb_data(:,1) = unix time
    % orb_data(:,2:4) = velocity x,y,z (GEO)
    % orb_data(:,5:7) = B Model x,y,z (GEO)
    % orb_data(:,8) = altitude (GEO)
    clearvars orb_data
    
    sa_matrix = [sa_data(:,1) sa_data(:,5:7)];
    % sa_matrix(:,1) = unix time
    % sa_matrix(:,2:4) = spin axis x,y,z (GEO)
    clearvars sa_data
    
    
    ef_matrix = [ef_data(:,1:2), ef_data(:,4)];
    % ef_matrix(:,1) = unix time
    % ef_matrix(:,2) = e-field x (DCS2)
    % ef_matrix(:,3) = e-field z (DCS2)
     clearvars ef_data
    

    %% Calculate VxB electric field contribution

    sa_geo_norm = sa_matrix(:,2:4);

    bmod_geo = orb_matrix(:,5:7);
    bmod_geo_norm = normr(bmod_geo);
    
    zdcs=normr(bmod_geo_norm - repmat(dot(bmod_geo_norm,sa_geo_norm,2),[1 3]).*sa_geo_norm);
    xdcs=normr(cross(sa_geo_norm, zdcs));

    vel_geo = orb_matrix(:,2:4)*1000; %convert from km to m

    Ez_VxB = -1*dot(cross(bmod_geo,vel_geo),zdcs,2);
    Ex_VxB = -1*dot(cross(bmod_geo,vel_geo),xdcs,2);


     %% Remove electric field contribution offset from electric field data

     ef_dcs_x = ef_matrix(:,2) - Ex_VxB;

     
     ef_dcs_z = ef_matrix(:,3) - Ez_VxB;


end