function [spin_axis_gei spin_axis_geo] = get_spin_axis(axis_data) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
%
% This function converts the spin axis to GEI and GEO coordiantes from
% spherical GEI (right asencion and declination angles).
%
% Input:
% axis_data - spin axis data in spherical GEI coordinates
%
% Output:
% spin_axis_gei - spin axis in GEI coordinates
% spin_axis_geo - spin axis in GEO coordinates
%
% Expected format of input matrix:
% axis_data(:,1) = unix time
% axis_data(:,2) = right asenscion angle
% axis_data(:,3) = declination angle
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    %If there are any NaNs in the spin axis data, remove them and extrapolate real data to original length
    if(any(any(isnan(axis_data(:,:))))) 
        spin_axis_gei_with_nans = axis_data;    
        axis_data(any(isnan(axis_data),2),:) = [];

        spin_axis_gei_extrap = interp1(axis_data(:,1), axis_data(:,2:3), spin_axis_gei_with_nans(:,1), 'linear', 'extrap');

        spin_x_gei = cosd(spin_axis_gei_extrap(:,2)).*cosd(spin_axis_gei_extrap(:,1));
        spin_y_gei = cosd(spin_axis_gei_extrap(:,2)).*sind(spin_axis_gei_extrap(:,1));
        spin_z_gei = sind(spin_axis_gei_extrap(:,2));
        
        sa_time = spin_axis_gei_with_nans(:,1);
    else 
        spin_x_gei = cosd(axis_data(:,3)).*cosd(axis_data(:,2));
        spin_y_gei = cosd(axis_data(:,3)).*sind(axis_data(:,2));
        spin_z_gei = sind(axis_data(:,3));
        
        sa_time = axis_data(:,1);
    end
    
    spin_axis_gei = [spin_x_gei, spin_y_gei, spin_z_gei];

    % Convert from GEI to GEO
    matlab_time = unixtime2mat2(sa_time);
    spin_axis_geo = onera_desp_lib_rotate(spin_axis_gei, 'gei2geo', matlab_time);

    spin_axis_gei = [sa_time, spin_axis_gei];
    spin_axis_geo = [sa_time, spin_axis_geo];

end