function [checked_orb, checked_ef, checked_mag] = orbit_stats(orb_data, ef_data, mag_data, time, lat, long, alt, dtime, dlat, dlong, dalt)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
%
% This function limits down the inputted data based on the inputted
% parameters. This is to be used in the 'statistics' mode of the top level
% function process_orbit.m. If the data is not valid for the inputted
% parameters, it sets a flag and breaks out of the function. This is used
% in conjunction with limit_check.m and orbit_stats_plot.m.
%
% Inputs: 
% orb_data - orbital data 
% ef_data - electric field data
% mag_data - magnetic field data
% time - starting time limit
% lat  - starting latitude limit
% long - starting longitude limit
% alt - starting altitude limit
% dtime - ending time limit
% dlat - ending latitude limit
% dlong - ending longitude limit
% dalt - ending altitude limit
%
% Outputs:
% checked_orb - orbital data limited by parameters
% checked_ef - electric field data limited by parameters
% checked_mag - magnetic field data limited by parameters
%
% Expected format of input matrices:
% orb_data{:,1}  = UNIX time
% orb_data{:,2}  = Pos x,y,z(GEI)
% orb_data{:,3}  = Vel x,y,z(GEI)
% orb_data{:,4}  = Pos x,y,z(GEO)
% orb_data{:,5}  = Vel x,y,z(GEO)
% orb_data{:,6}  = Altitude (km) 
% orb_data{:,7}  = Latitude (deg)
% orb_data{:,8}  = Longitude (deg)
% orb_data{:,9}  = Invariant Latitude (deg)
% orb_data{:,10} = Magnetic Local Time
% orb_data{:,11} = B Model x,y,z (GEI)
% orb_data{:,12} = B Footprint (mapped to 100 km)
% orb_data{:,13} = Latitude Footprint (geodectic)
% orb_data{:,14} = Longitude Footpring (geodectic)
%
% ef_data{:,1}   = UNIX time
% ef_data{:,2}   = E near B (E_z (DCS))
% ef_data{:,3}   = E along V (E_x (DCS))
%
% mag_data{:,1}    = UNIX time
% mag_data{:,2:4}  = Delta-B x,y,z (GEI)
% mag_data{:,5:7}  = Total B x,y,z (GEI)
% mag_data{:,8:10} = Delta-B (FAC_V)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Global flag, which indicates if the time limit set by the input
    % has been found within the orbit range. If it has not yet been found
    % this flag is set to 0 and the program keeps searching through the
    % orbits. If the time range has been found, the flag is set to 1 and
    % the program keeps searching through the orbits. However, if the time
    % range has been found already (indicated by a flag of 1) but the time
    % range is no longer valid within the orbit currently being checked,
    % then the flag is set to 2 indicating that the time range is no longer
    % valid.
    global valid_range_flag;

    try
        %Read in and setup initial orbit, electric field, and magnetic field
        %matrices
        orb_all = [orb_data{:,1}, orb_data{:,6:8}];
        %orb_all(:,1)       = unix time
        %orb_all(:,2:4)     = altitude, latitude, longitude (degrees)
        clearvars orb_data

        ef_all = [ef_data{:,1}, ef_data{:,3}, ef_data{:,2}];
        %ef_all(:,1)      = unix time
        %ef_all(:,2)      = electric field x (DCS2)
        %ef_all(:,3)      = electric field z (DCS2)
        clearvars ef_data

        mag_all = [mag_data{:,1:7}];
        %mag_all(:,1)        = unix time
        %mag_all(:,2:4)      = Delta-b x,y,z (GEI)
        %mag_all(:,5:7)      = Total B x,y,z (GEI)  
        clearvars mag_data

        %Downsample and smooth the electric field and magnetic field data
        [down_smooth_ef down_smooth_mag] = down_smooth(ef_all,2,3,mag_all,2,7);

        %Give the electric field and magnetic field data a latitude, longitude, and
        %altitude componenet
        [ef_all, lla_ef] = data_interp(down_smooth_ef, orb_all); 
        [mag_all, lla_mag] = data_interp(down_smooth_mag, orb_all);

        ef_lla = [ef_all, lla_ef(:,2:4)];
        %uv_e_lla(:,1)      = unix time
        %uv_e_lla(:,2)      = electric field x (DCS2)
        %uv_e_lla(:,3)      = electric field z (DCS2)
        %uv_e_lla(:,4:6)    = altitude, latitude, longitude (degrees)

        mag_lla = [mag_all, lla_mag(:,2:4)];
        %mag_lla(:,1)        = unix time
        %mag_lla(:,2:4)      = delta-b x,y,z (GEI)
        %mag_lla(:,5:7)      = B x,y,z (GEI)  
        %mag_lla(:,8:10)     = altitude, latitude, longitude (degrees)
    catch exception
        fprintf([getReport(exception,'basic', 'hyperlinks', 'off') '\n']);
        checked_orb = [];
        checked_ef = []; 
        checked_mag = [];
        return;
    end
while(1)

    orb_time = orb_all(:,1);
    ef_time = ef_lla(:,1);
    mag_time = mag_lla(:,1);
    
    %Limit the input data matrices by the time range set by the input
    %parameters
    if(~isempty(orb_all) && ~isempty(ef_lla) && ~isempty(mag_lla))
        if(~(min(orb_time)>dtime || max(orb_time)<time) &&  ~(min(ef_time)>dtime || max(ef_time)<time) &&  ~(min(mag_time)>dtime || max(mag_time)<time))
            orb_tcheck = orb_all(orb_time>=time & orb_time<=dtime,:);   
            ef_tcheck  = ef_lla(ef_time>=time & ef_time<=dtime,:);  
            mag_tcheck = mag_lla(mag_time>=time & mag_time<=dtime,:);  
            clearvars orb_all ef_lla mag_lla
            valid_range_flag = 1;        %indicate that the orbit time packet has been found and is being used
        else
            if valid_range_flag == 1        %if valid_range_flag shows that the time range had been found and is no longer valid
                valid_range_flag = 2;       %then indicate that all orbits have been found
            else                            %else if it shows that the time range has not yet been found
                valid_range_flag = 0;       %then indicate that the orbits have not yet been found
            end

            checked_orb = [];
            checked_ef  = [];
            checked_mag = [];
            break;                       %orbit not valid, stop checking parameters
        end
    else
        if valid_range_flag == 1        %if valid_range_flag shows that the time range had been found and is no longer valid
            valid_range_flag = 2;       %then indicate that all orbits have been found
        else                            %else if it shows that the time range has not yet been found
            valid_range_flag = 0;       %then indicate that the orbits have not yet been found
        end

        checked_orb = [];
        checked_ef  = [];
        checked_mag = [];
        break;                       %orbit not valid, stop checking parameters
    end

    orb_lat = orb_tcheck(:,3);
    ef_lat  = ef_tcheck(:,5);
    mag_lat = mag_tcheck(:,9);

    
    %Limit the input data matrices by the latitude range set by the input
    %parameters
    if(~isempty(orb_tcheck) && ~isempty(ef_tcheck) && ~isempty(mag_tcheck))
        if(~(min(orb_lat)>dlat || max(orb_lat)<lat) &&  ~(min(ef_lat)>dlat || max(ef_lat)<lat) &&  ~(min(mag_lat)>dlat || max(mag_lat)<lat))
            orb_latcheck = orb_tcheck(orb_lat>=lat & orb_lat<=dlat,:);   
            ef_latcheck  = ef_tcheck(ef_lat>=lat & ef_lat<=dlat,:);   
            mag_latcheck = mag_tcheck(mag_lat>=lat & mag_lat<=dlat,:);   
            clearvars orb_tcheck ef_tcheck mag_tcheck
        else
             checked_orb = [];
             checked_ef  = [];
             checked_mag = [];
             break;                     %orbit not valid, stop checking parameters
        end
    else
         checked_orb = [];
         checked_ef  = [];
         checked_mag = [];
         break;                     %orbit not valid, stop checking parameters
    end

    orb_long = orb_latcheck(:,4);
    ef_long  = ef_latcheck(:,6);
    mag_long = mag_latcheck(:,10);

    %Limit the input data matrices by the longitude range set by the input
    %parameters
    if(~isempty(orb_latcheck) && ~isempty(ef_latcheck) && ~isempty(mag_latcheck))
        if(~(min(orb_long)>dlong || max(orb_long)<long) &&  ~(min(ef_long)>dlong || max(ef_long)<long) &&  ~(min(mag_long)>dlong || max(mag_long)<long))
            orb_longcheck = orb_latcheck(orb_long>=long & orb_long<=dlong,:);   
            ef_longcheck  = ef_latcheck(ef_long>=long & ef_long<=dlong,:);   
            mag_longcheck = mag_latcheck(mag_long>=long & mag_long<=dlong,:);   
            clearvars orb_latcheck ef_latcheck mag_latcheck
        else
             checked_orb = [];
             checked_ef  = [];
             checked_mag = [];
             break;                       %orbit not valid, stop checking parameters
        end
    else
         checked_orb = [];
         checked_ef  = [];
         checked_mag = [];
         break;                       %orbit not valid, stop checking parameters
    end

    orb_alt = orb_longcheck(:,2);
    ef_alt  = ef_longcheck(:,4);
    mag_alt = mag_longcheck(:,8);   
    
    %Limit the input data matrices by the altitude range set by the input
    %parameters
    if(~isempty(orb_longcheck) && ~isempty(ef_longcheck) && ~isempty(mag_longcheck))
        if(~(min(orb_alt)>dalt || max(orb_alt)<alt) &&  ~(min(ef_alt)>dalt || max(ef_alt)<alt) &&  ~(min(mag_alt)>dalt || max(mag_alt)<alt))
            orb_altcheck = orb_longcheck(orb_alt>=alt & orb_alt<=dalt,:);   %then only take parts of data that fit the input alt parameters
            ef_altcheck = ef_longcheck(ef_alt>=alt & ef_alt<=dalt,:);   %then only take parts of data that fit the input alt parameters
            mag_altcheck = mag_longcheck(mag_alt>=alt & mag_alt<=dalt,:);   %then only take parts of data that fit the input alt parameters

            % Convert the delta-B data form gei to geo
            db_GEI = mag_altcheck(:,2:4);
            matlabd = unixtime2mat2(mag_altcheck(:,1));
            db_GEO = onera_desp_lib_rotate(db_GEI,'gei2geo',matlabd);

            b_GEI = mag_altcheck(:,5:7);
            b_GEO = onera_desp_lib_rotate(b_GEI,'gei2geo',matlabd);

            mag_altcheck(:,2:4) = db_GEO;
            mag_altcheck(:,5:7) = b_GEO;

            checked_orb = orb_altcheck;
            checked_ef  = ef_altcheck;
            checked_mag = mag_altcheck;
            break;                      %all parameters checked and used  
        else
             checked_orb = [];
             checked_ef  = [];
             checked_mag = [];
             break;                     %orbit not valid, stop checking parameters
        end
        
    else
         checked_orb = [];
         checked_ef  = [];
         checked_mag = [];
         break;                     %orbit not valid, stop checking parameters
    end
end

return