function orbit_stats_plots(time, lat, lng, alt, dtime, dlat, dlng, dalt, tmp_directory)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
%
% This function accepts a series of limiting parameters and creates
% histograms of delta-B, total-B, and electric field data. This function is
% called by the top level function process_orbit.m, and is used in 
% conjunction with orbit_stats.m and limit_check.m. After plotting, 
% this function deletes all data in the temporary directory. The histograms
% are limited by a series of input parameters: time, latitude, and
% altitude.
%
% Inputs:
% time - starting Unix time (limiting parameter)
% lat - starting latitude in degrees (limiting parameter)
% alt - starting altitude in km (limiting parameter)
% dtime - ending Unix time (limiting parameter)
% dlat - ending latitude in degrees (limiting parameter)
% dlng - ending latitude in degrees (limiting parameter)
% tmp_directory - location containing temporary data created by 
% orbit_stats.m and used to create the histograms
%
% Outputs: 3 histograms showing delta-B, total-B, and electric field data
% for a given Unix time range and limited by a seris of input parameters.
%
% Expected format of data in temporary directory:
% checked_orb(:,1)       = unix time
% checked_orb(:,2:4)     = altitude, latitude, longitude (degrees)
%
% checked_ef(:,1)        = unix time
% checked_ef(:,2)        = electric field x (DCS2)
% checked_ef(:,3)        = electric field z (DCS2)
% checked_ef(:,4:6)      = altitude, latitude, longitude (degrees)
%
% checked_mag(:,1)       = unix time
% checked_mag(:,2:4)     = delta-b x,y,z (GEI)
% checked_mag(:,5:7)     = B x,y,z (GEI)  
% checked_mag(:,8:10)    = altitude, latitude, longitude (degrees)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Overall minimum and maximum values of data that will be used to correctly
% bin the data in the histograms. Created in limit_check.m.
    global min_max_vals
 
% Get a listing of all files, in all folders (orbit, electric field,
% magnetic field) of the temporary directory that holds the data for the 
% histograms.
    orb_dir = dir(strcat(tmp_directory, 'orb'));    
    ef_dir = dir(strcat(tmp_directory, 'ef'));    
    mag_dir = dir(strcat(tmp_directory, 'mag'));   

%If there are valid files in the orbit, electric field, and magnetic
%field directories, then make histograms of data.
    if(length(orb_dir)>=3 && length(ef_dir)>=3 && length(mag_dir)>=3)

    %Set the divison intervals for the histograms (hard coded)
        div_dbx = 3;
        div_dby = 2;
        div_dbz = 1;

        div_bx = 200;
        div_by = 200;
        div_bz = 200;

        div_mlat = 1;
        div_mlng = 1;
        div_malt = 20;

        div_olat = 1;
        div_olng = 1;
        div_oalt = 20;

        div_elat = 1;
        div_elng = 1;
        div_ealt = 20;

    %Create the matrixes to hold the final summed histogram data
    %Orbital Data Latitude, Longitude, Altitude Histogram
        olat_hist(:,1) = (min_max_vals.orb_lat(1):div_olat:min_max_vals.orb_lat(2))'; 
        olat_hist(:,2) = zeros(length(olat_hist(:,1)),1);
        olng_hist(:,1) = (min_max_vals.orb_lng(1):div_olng:min_max_vals.orb_lng(2))'; 
        olng_hist(:,2) = zeros(length(olng_hist(:,1)),1);
        oalt_hist(:,1) = (min_max_vals.orb_alt(1):div_oalt:min_max_vals.orb_alt(2))'; 
        oalt_hist(:,2) = zeros(length(oalt_hist(:,1)),1);
        %Delta-B Histogram 
        dbx_hist(:,1) = (min_max_vals.db_x(1):div_dbx:min_max_vals.db_x(2))'; 
        dbx_hist(:,2) = zeros(length(dbx_hist(:,1)),1);
        dby_hist(:,1) = (min_max_vals.db_y(1):div_dby:min_max_vals.db_y(2))'; 
        dby_hist(:,2) = zeros(length(dby_hist(:,1)),1);
        dbz_hist(:,1) = (min_max_vals.db_z(1):div_dbz:min_max_vals.db_z(2))'; 
        dbz_hist(:,2) = zeros(length(dbz_hist(:,1)),1);
        %Total-B Histogram 
        bx_hist(:,1) = (min_max_vals.b_x(1):div_bx:min_max_vals.b_x(2))'; 
        bx_hist(:,2) = zeros(length(bx_hist(:,1)),1);
        by_hist(:,1) = (min_max_vals.b_y(1):div_by:min_max_vals.b_y(2))'; 
        by_hist(:,2) = zeros(length(by_hist(:,1)),1);
        bz_hist(:,1) = (min_max_vals.b_z(1):div_bz:min_max_vals.b_z(2))'; 
        bz_hist(:,2) = zeros(length(bz_hist(:,1)),1);
        %Magnetic Field Latitude, Longitude, Altitude Histogram
        mlat_hist(:,1) = (min_max_vals.mag_lat(1):div_mlat:min_max_vals.mag_lat(2))'; 
        mlat_hist(:,2) = zeros(length(mlat_hist(:,1)),1);
        mlng_hist(:,1) = (min_max_vals.mag_lng(1):div_mlng:min_max_vals.mag_lng(2))'; 
        mlng_hist(:,2) = zeros(length(mlng_hist(:,1)),1);
        malt_hist(:,1) = (min_max_vals.mag_alt(1):div_malt:min_max_vals.mag_alt(2))'; 
        malt_hist(:,2) = zeros(length(malt_hist(:,1)),1);
        %Electric Field Latitude, Longitude, Altitude Histogram
        elat_hist(:,1) = (min_max_vals.e_lat(1):div_elat:min_max_vals.e_lat(2))'; 
        elat_hist(:,2) = zeros(length(elat_hist(:,1)),1);
        elng_hist(:,1) = (min_max_vals.e_lng(1):div_elng:min_max_vals.e_lng(2))'; 
        elng_hist(:,2) = zeros(length(elng_hist(:,1)),1);
        ealt_hist(:,1) = (min_max_vals.e_alt(1):div_ealt:min_max_vals.e_alt(2))'; 
        ealt_hist(:,2) = zeros(length(ealt_hist(:,1)),1);

    %For all files in the orb, ef, and mag directories, sum up the
    %total numbers of data per divison to create overall histograms
        for j = 3:1:length(mag_dir)
            
        %Load in the current files
            load(strcat(tmp_directory, 'orb\', orb_dir(j).name));
            load(strcat(tmp_directory, 'ef\', ef_dir(j).name));
            load(strcat(tmp_directory, 'mag\', mag_dir(j).name));

        % Create summed data to be used in the histograms (bar graphs)
        % *********************Delta-B*****************************************
            dbx_hist(:,2) = (dbx_hist(:,2) + histc(checked_mag(:,2),dbx_hist(:,1)));
            dby_hist(:,2) = (dby_hist(:,2) + histc(checked_mag(:,3),dby_hist(:,1)));
            dbz_hist(:,2) = (dbz_hist(:,2) + histc(checked_mag(:,4),dbz_hist(:,1)));
            
        % *********************Total-B*****************************************
            bx_hist(:,2) = (bx_hist(:,2) + histc(checked_mag(:,5),bx_hist(:,1)));
            by_hist(:,2) = (by_hist(:,2) + histc(checked_mag(:,6),by_hist(:,1)));
            bz_hist(:,2) = (bz_hist(:,2) + histc(checked_mag(:,7),bz_hist(:,1)));
            
        % **************Magnetic Field Latatitude, Longitude, Altitude*********
            mlat_hist(:,2) = (mlat_hist(:,2) + histc(checked_mag(:,9),mlat_hist(:,1)));
            mlng_hist(:,2) = (mlng_hist(:,2) + histc(checked_mag(:,10),mlng_hist(:,1)));
            malt_hist(:,2) = (malt_hist(:,2) + histc(checked_mag(:,8),malt_hist(:,1)));
            
        % **************Orbit File Total Latatitude, Longitude, Altitude*******
            olat_hist(:,2) = (olat_hist(:,2) + histc(checked_orb(:,3),olat_hist(:,1)));
            olng_hist(:,2) = (olng_hist(:,2) + histc(checked_orb(:,4),olng_hist(:,1)));
            oalt_hist(:,2) = (oalt_hist(:,2) + histc(checked_orb(:,2),oalt_hist(:,1)));
            
        % *********Electric Field File  Latatitude, Longitude, Altitude*******
            elat_hist(:,2) = (elat_hist(:,2) + histc(checked_ef(:,5),elat_hist(:,1)));
            elng_hist(:,2) = (elng_hist(:,2) + histc(checked_ef(:,6),elng_hist(:,1)));
            ealt_hist(:,2) = (ealt_hist(:,2) + histc(checked_ef(:,4),ealt_hist(:,1))); 
        end

    %Format the start time, end time, and degree sign for display on
    %the histograms
        starttime = datestr(unixtime2mat2(time));  
        endtime = datestr(unixtime2mat2(dtime));
        deg = sprintf('%c', char(176));

    % Plot Histograms
        % ****************Orbit Data***************************************
        
        figure('name','Histogram of Latitude, Longitude, Altitude (Full Orbit)');
        subplot(3,1,1);bar(olat_hist(:,1),olat_hist(:,2));xlim([min_max_vals.orb_lat(1) min_max_vals.orb_lat(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                '';
                'Latitude'});
        xlabel('Degrees');ylabel('Number of Values');
        subplot(3,1,2);bar(olng_hist(:,1),olng_hist(:,2));xlim([min_max_vals.orb_lng(1) min_max_vals.orb_lng(2)]);title('Longitude');xlabel('Degrees');ylabel('Number of Values');
        subplot(3,1,3);bar(oalt_hist(:,1),oalt_hist(:,2));xlim([min_max_vals.orb_alt(1) min_max_vals.orb_alt(2)]);title('Altitude');xlabel('km');ylabel('Number of Values');
        
        
        % ***************Electric Field Data*******************************
        
        figure('name','Histogram of Latitude, Longitude, Altitude (Electric Field)');
        subplot(3,1,1);bar(elat_hist(:,1),elat_hist(:,2));xlim([min_max_vals.e_lat(1) min_max_vals.e_lat(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                '';
                'Latitude'});
        xlabel('Degrees');ylabel('Number of Values');
        subplot(3,1,2);bar(elng_hist(:,1),elng_hist(:,2));xlim([min_max_vals.e_lng(1) min_max_vals.e_lng(2)]);title('Longitude');xlabel('Degrees');ylabel('Number of Values');
        subplot(3,1,3);bar(ealt_hist(:,1),ealt_hist(:,2));xlim([min_max_vals.e_alt(1) min_max_vals.e_alt(2)]);title('Altitude');xlabel('km');ylabel('Number of Values');

        % ***************Magnetic Field Data*******************************
        %Subplots
        figure('name','Histogram of Delta-B X,Y,Z');
        subplot(3,1,1);bar(dbx_hist(:,1),dbx_hist(:,2),'HitTestArea', 'on');xlim([min_max_vals.db_x(1) min_max_vals.db_x(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                ''; 
                'Delta-B_X'});
        xlabel('nT');ylabel('Number of Values');
        subplot(3,1,2);bar(dby_hist(:,1),dby_hist(:,2));xlim([min_max_vals.db_y(1) min_max_vals.db_y(2)]);title('Delta-B_Y');xlabel('nT');ylabel('Number of Values');
        subplot(3,1,3);bar(dbz_hist(:,1),dbz_hist(:,2));xlim([min_max_vals.db_z(1) min_max_vals.db_z(2)]);title('Delta-B_Z');xlabel('nT');ylabel('Number of Values');

        %Individual plots
        figure('name','Histogram of Delta-B_X');
        bar(dbx_hist(:,1),dbx_hist(:,2),'HitTestArea', 'on');xlim([min_max_vals.db_x(1) min_max_vals.db_x(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                ''; 
                'Delta-B_X'});
        xlabel('nT');ylabel('Number of Values');
        
        figure('name','Histogram of Delta-B_Y');
        bar(dby_hist(:,1),dby_hist(:,2));xlim([min_max_vals.db_y(1) min_max_vals.db_y(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                ''; 
                'Delta-B_Y'});
        xlabel('nT');ylabel('Number of Values');
        
        figure('name','Histogram of Delta-B_Z');
        bar(dbz_hist(:,1),dbz_hist(:,2));xlim([min_max_vals.db_z(1) min_max_vals.db_z(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                ''; 
                'Delta-B_Z'});
        xlabel('nT');ylabel('Number of Values');

        %Subplots
        figure('name','Histogram of Total-B X,Y,Z');
        subplot(3,1,1);bar(bx_hist(:,1),bx_hist(:,2));xlim([min_max_vals.b_x(1) min_max_vals.b_x(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                '';
                'Total-B_X'});
        xlabel('nT');ylabel('Number of Values');
        subplot(3,1,2);bar(by_hist(:,1),by_hist(:,2));xlim([min_max_vals.b_y(1) min_max_vals.b_y(2)]);title('Total-B_Y');xlabel('nT');ylabel('Number of Values');
        subplot(3,1,3);bar(bz_hist(:,1),bz_hist(:,2));xlim([min_max_vals.b_z(1) min_max_vals.b_z(2)]);title('Total-B_Z');xlabel('nT');ylabel('Number of Values');

        %Individual plots
        figure('name','Histogram of Total-B_X');
        bar(bx_hist(:,1),bx_hist(:,2));xlim([min_max_vals.b_x(1) min_max_vals.b_x(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                '';
                'Total-B_X'});
        xlabel('nT');ylabel('Number of Values');
        
        figure('name','Histogram of Total-B_Y');
        bar(by_hist(:,1),by_hist(:,2));xlim([min_max_vals.b_y(1) min_max_vals.b_y(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                '';
                'Total-B_Y'});
        xlabel('nT');ylabel('Number of Values');
        
        figure('name','Histogram of Total-B_Z');
        bar(bz_hist(:,1),bz_hist(:,2));xlim([min_max_vals.b_z(1) min_max_vals.b_z(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                '';
                'Total-B_Z'});
        xlabel('nT');ylabel('Number of Values');
        
        %Subplots
        figure('name','Histogram of Latitude, Longitude, Altitude (Magnetic Field)');
        subplot(3,1,1);bar(mlat_hist(:,1),mlat_hist(:,2));xlim([min_max_vals.mag_lat(1) min_max_vals.mag_lat(2)]);
        title({[starttime ' to ' endtime];
               ['Latitude: ' int2str(lat) ' to ' int2str(dlat) deg ', Longitude: ' int2str(lng) ' to ' int2str(dlng) deg ', Altitude: ' int2str(alt) ' to ' int2str(dalt) ' km'];
                '';
                'Latitude'});
        xlabel('Degrees');ylabel('Number of Values');
        subplot(3,1,2);bar(mlng_hist(:,1),mlng_hist(:,2));xlim([min_max_vals.mag_lng(1) min_max_vals.mag_lng(2)]);title('Longitude');xlabel('Degrees');ylabel('Number of Values');
        subplot(3,1,3);bar(malt_hist(:,1),malt_hist(:,2));xlim([min_max_vals.mag_alt(1) min_max_vals.mag_alt(2)]);title('Altitude');xlabel('km');ylabel('Number of Values');

 
    % Delete all files in the directories holding the temporary data
    % for the "statistics" function
        rmdir(strcat(tmp_directory, '*'),'s')
        
    else
       fprintf('Latitude, Longitude, or Altitude range not valid for given timespan.\n'); 
    end

end
