function polar_plot(valid_orbs, fastdata, processeddata, tmp_dir, mlt, mlat, alt, dmlt, dmlat, dalt, interval)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
% Co-Author: Steven Chen
%
% This function creates a binned statistical (emperical) model of the
% average Poynting flux and contributing crossings based on a series of
% input parameters.
%
% Inputs:
% valid_orb - matrix listing the valid orbit numbers and corresponding
% starting times for the valid kp indices that fall within an orbit range
% fastdata - directory where the exported FAST data is stored
% processeddata - directory where the processed FAST data is stored
% tmp_dir - temporary directory where limited data will be stored
% mlt - starting magnetic local time (limiting parameter)
% mlat - starting invariant latitude (limiting parameter)
% alt - starting altitude (limiting parameter)
% dmlt - ending magnetic local time (limiting parameter)
% dmlat - ending invariant latitude (limiting parameter)
% dalt - ending altitude (limiting parameter)
% interval - number of bins to plot (hard coded to 24 in process_orbit.m)
%
%
% NOTE: For more information on the polar3d function please visit 
% http://www.mathworks.com/matlabcentral/fileexchange/7656-3d-polar-plot
% There is a descriptive PDF attached with the download that will further
% explain the methods used in the polar plots.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    for j = 1:length(valid_orbs)

        valid_range_flag = 0;   %set flag to indicate whether any orbits 
                                %within the time range of the current kp 
                                %unix time have been found
                                
        k = -1;     %initiate counter for looping through orbits within one kp unix time range
        
        while (valid_range_flag ~= 2)
            
            k = k+1;    %increment counter pointing to current orbit
            
            orbitnum = int2str((valid_orbs(j,1)+k));  
                
            %correct the orbit name to the naming standard
            while(length(orbitnum) ~= 5)        
                orbitnum = strcat('0', orbitnum);
            end
            orbitname = strcat('fa_k0_', orbitnum);
            
            
            %Try to load in pre-processed Poynting flux data
            %If this fails because no processed data exists, process the 
            %Poynting flux for the given orbit and save the result.
            try 
                load(strcat(processeddata,'\PoyntingFlux\', orbitname,'\', orbitname,'_geo'));          
            catch exception
                getReport(exception,'basic', 'hyperlinks', 'off');

                eesorbitname = strcat('fa_k0_ees_',orbitnum,'_v04.cdf');                
                iesorbitname = strcat('fa_k0_ies_',orbitnum,'_v04.cdf');

                fastdir = strcat(fastdata,orbitname, '\');

                orb_path = strcat(fastdir, orbitname, '_orb.cdf');
                ef_path = strcat(fastdir, orbitname, '_ef.cdf');
                db_path = strcat(fastdir, orbitname, '_mag.cdf');
                sa_path = strcat(fastdir,orbitname, '_sa.cdf');
                ees_path = strcat(fastdir, eesorbitname);
                ies_path = strcat(fastdir, iesorbitname);


                    if(exist(orb_path, 'file') == 2 ...
                        && exist(ef_path, 'file') == 2 ...
                        && exist(db_path, 'file') == 2 ...
                        && exist(sa_path, 'file') == 2 ...
                        && exist(ies_path, 'file') == 2 ...
                        && exist(ees_path, 'file') == 2)
                       
                        try
                        orb_data = cdfread(orb_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'FA_POSGEI'},{'FA_VELGEI'},{'FA_POS'},{'FA_VEL'},{'ALT'},{'LAT'},{'LNG'},{'ILAT'},{'MLT'},{'B_MODEL'},{'B_FOOT'},{'FOOT_LAT'},{'FOOT_LNG'}]);
                        %orb_data{:,1}  = UNIX time
                        %orb_data{:,2}  = Pos x,y,z(GEI)
                        %orb_data{:,3}  = Vel x,y,z(GEI)
                        %orb_data{:,4}  = Pos x,y,z(GEO)
                        %orb_data{:,5}  = Vel x,y,z(GEO)
                        %orb_data{:,6}  = Altitude (km) 
                        %orb_data{:,7}  = Latitude (deg)
                        %orb_data{:,8}  = Longitude (deg)
                        %orb_data{:,9}  = Invariant Latitude (deg)
                        %orb_data{:,10} = Magnetic Local Time
                        %orb_data{:,11} = B Model x,y,z (GEI)
                        %orb_data{:,12} = B Footprint (mapped to 100 km)
                        %orb_data{:,13} = Latitude Footprint (geodectic)
                        %orb_data{:,14} = Longitude Footpring (geodectic)
                        
                        ef_data = cdfread(ef_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'E_NEAR_B'},{'E_ALONG_V'}]);
                        %ef_data{:,1}   = UNIX time
                        %ef_data{:,2}   = E near B (E_z (DCS))
                        %ef_data{:,3}   = E along V (E_x (DCS))
                        
                        mag_data = cdfread(db_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'DB_GEI_O'},{'DB_GEI_E'},{'DB_GEI_B'},{'B_GEI_O'},{'B_GEI_E'},{'B_GEI_B'},{'DB_FAC_V_O'},{'DB_FAC_V_E'},{'DB_FAC_V_B'}]);
                        %mag_data{:,1}    = UNIX time
                        %mag_data{:,2:4}  = Delta-B x,y,z (GEI)
                        %mag_data{:,5:7}  = Total B x,y,z (GEI)
                        %mag_data{:,8:10} = Delta-B (FAC_V)
                        
                        sa_data = cdfread(sa_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'}, {'FA_SPIN_RA'}, {'FA_SPIN_DEC'}]);
                        %sa_data{:,1}   = UNIX time
                        %sa_data{:,2}   = Right Asenscion Angle (deg)
                        %sa_data{:,3}   = Declination Angle (deg)
                        
                        ees_data = cdfread(ees_path, 'CombineRecords', true, 'Variable', [{'TIME'},{'JEe'}]);
                        %ees_data{:,1}   = UNIX time
                        %ees_data{:,2}   = Kinetic Energy Flux(Electron)(W/m^2)     
                        
                        ies_data = cdfread(ies_path, 'CombineRecords', true, 'Variable', [{'TIME'},{'JEi'}]);
                        %ies_data{:,1}   = UNIX time
                        %ies_data{:,2}   = Kinetic Energy Flux(Ion)(W/m^2)  
                        
                        catch exception
                            fprintf([getReport(exception,'basic', 'hyperlinks', 'off') '\n']);
                            cprintf('red', 'Unable to read the right data values from CDF for orbit %d.\n', currOrbit);
                            continue
                        end

                        orb_time = uint32(orb_data{:,1});
                        ef_time = uint32(ef_data{:,1});
                        db_time = uint32(mag_data{:,1});
                        sa_time = uint32(sa_data{:,1});
                        ees_time = uint32(ees_data{:,1});
                        ies_time = uint32(ies_data{:,1});

                        end_times = [orb_time(end), sa_time(end)];
                        start_times = [orb_time(1), sa_time(1)];

                        if((db_time(end) >= orb_time(1) ...
                                && db_time(1) <= orb_time(end)) ...
                                && (sa_time(end) >= orb_time(1) ...
                                && sa_time(1) <=orb_time(end)))
                            if((ef_time(1) >= max(start_times) ...
                                    && ef_time(end) <= min(end_times))  ...
                                    && (ees_time(1) >= max(start_times) ...
                                    && ees_time(end) <= min(end_times)) ...
                                    && (ies_time(1) >= max(start_times) ...
                                    && ies_time(end) <= min(end_times)))
                                valid_timespan = true;
                            else
                                valid_timespan = false;
                            end
                        else
                            valid_timespan = false;
                        end
                        
                        %If files are valid, process data for the Poynting flux
                        if valid_timespan 
                            try
                                [~, output_data_geo] = process_flux(orb_data, ef_data, mag_data, ees_data, ies_data, sa_data, orbitname, processeddata);
                            catch exception
                                getReport(exception,'basic', 'hyperlinks', 'off');
                                cprintf('red', 'Failed with orbit %d.\n', str2double(orbitnum));
                                continue;
                            end
                        else 
                            continue;
                        end
                    end
            end
            
            
            time_start = valid_orbs(j,2);
            time_data = output_data_geo(:,1);
            
            %Determine if the current orbit reaches the end of the 3 hour
            %time span for the kp index time. If it does then indicate with
            %the valid_range_flag that the program does not have to keep
            %checking orbits to see if they are valid.
            if (time_data(end) >= (time_start + 10800))
                valid_range_flag = 2;   %indicates that the range is fully in this one orbit
            end
            
            %limit Poynting data to within the designated Unix time range
            mlt_geo_limit = output_data_geo(time_data>=time_start & time_data<=(time_start+10800),:);  
            
            %if there is still data after limiting by mlt, then continue
            if ~isempty(mlt_geo_limit)
                
                if (valid_range_flag == 0)
                    valid_range_flag = 1; %indicates that the range is not fully in this one orbit but has been found
                end
                
                mlt_data = mlt_geo_limit(:,15);
                
                %limit data by designated magnetic local time range
                mlt_geo = mlt_geo_limit(mlt_data>=mlt & mlt_data<=dmlt,:);

                if ~isempty(mlt_geo)
                    
                    mlat_data = mlt_geo(:,16);
                    
                    %limit data by designated invariant latitude
                    mlat_geo = mlt_geo(mlat_data>=mlat & mlat_data<=dmlat,:);

                    if ~isempty(mlat_geo)
                        
                        alt_data = mlat_geo(:,2);
                        
                        %limit data by designated altitude
                        alt_geo = mlat_geo(alt_data>=alt & alt_data<=dalt,:);
                        
                        if ~isempty(alt_geo)
                            save(strcat(tmp_dir, orbitnum, '_', int2str(j)), 'alt_geo');
                        else
                            continue;
                        end
                    else
                        continue;
                    end
                else
                    continue;
                end
            else
                if valid_range_flag == 0;
                    valid_range_flag = 0;	%indicate range not yet found
                else 
                    valid_range_flag = 2;	%indicate range found and range done
                    continue;
                end
            end
        end
    end
    
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%% Make polar plots %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % Get the average Poynting flux and crossings matrices
    [zin crossings]= zin_for_polar3D(tmp_dir, mlt, mlat, dmlt, dmlat, interval);
    
    % If there are any values in the Poytning matrix, then plot
    if any(any(~isnan(zin(:,:))))
        
        % Create header for plot figure
        if (mlat >= 0 && dmlat >= 0)
            hemisphere = 'Northern ';
        elseif(mlat <= 0 && dmlat <= 0)
            hemisphere = 'Southern ';
        else
            hemisphere = 'Northern & Southern ';
        end
        
        %Create plot of average Poynting flux
        figure('name',[hemisphere, 'Hemisphere']);
        P = zin;
        P(isnan(P))=0; % set all NaN values to 0 
        Z = zeros(size(P));
        polar3d(P,0,2*pi,0,1,1,'surf');
        shading flat
        hold on
        polar3d(Z',0,2*pi,1,1.001,1,'meshl');
        hold off
        view([90 90]) %fix view of plot
        colorbar % add colorbar
        
        % Format labels around the plot to magnetic local time
        ph=findall(gca,'type','text');
        ps=get(ph,'string');
        ps(1:18)={''};
        ps([7,8,9,10,11,12,13,14,15,16,17,18])={
        '22:00'
        '20:00'
        '18:00'
        '16:00'
        '14:00'
        '12:00'
        '10:00'
        '08:00'
        '06:00'
        '04:00'
        '02:00'
        '00:00'
        };
        set(ph,{'string'},ps);
        
        % Format color bar labels
        cbar_axes = colorbar('peer',gca);
        tmp=get(cbar_axes);
        ytick = tmp.YTickLabel;
        nan_string = 'NaN';
        for j = 1:length(ytick)
            space_array(j,1:2) = sprintf('%c%c', char(32),char(32));
        end
        ytick = [ytick,space_array];

        for i = 1: size(ytick,1)
            if(strcmp(deblank(ytick(i,1:end)),'0'))
                while(length(nan_string) ~= length(ytick(1,:)))
                    nan_string = [nan_string, ' '];
                end
            ytick(i,1:end) = nan_string;
            end
        end
        
        set(cbar_axes, 'YTickLabel', ytick);
        
        % Format plot perspective
        daspect('auto')
        pbaspect('auto')
        
        %Create plot of contributing crossings
        figure('name',[hemisphere, 'Crossings']);
        P = crossings;
        P(isnan(P))=0;
        Z = zeros(size(P));
        polar3d(P,0,2*pi,0,1,1,'surf');
        shading flat
        hold on
        polar3d(Z',0,2*pi,1,1.001,1,'meshl');
        hold off
        view([90 90]) %fix view
        colorbar %turn on colorbar
        
        % Format labels around the plot to magnetic local time
        ph=findall(gca,'type','text');
        ps=get(ph,'string');
        ps(1:18)={''};
        ps([7,8,9,10,11,12,13,14,15,16,17,18])={
        '22:00'
        '20:00'
        '18:00'
        '16:00'
        '14:00'
        '12:00'
        '10:00'
        '08:00'
        '06:00'
        '04:00'
        '02:00'
        '00:00'
        };
        set(ph,{'string'},ps);
        
        % Format plot perspective
        daspect('auto')
        pbaspect('auto')
        
    else
       fprintf('No valid data found. Could not plot results.'); 
    end
    
end