function process_orbit(mode, varargin)
%% PROCESS_ORBIT 
%
%   AUTHOR: Steven Chen      1/21/11
%
%
%   The purpose of this function is to search through a known directory for
%   where the fast data is stored in order to grab the listed orbits
%   inputted upon function call, process the data and save the data in a
%   different directory
%
%   This is a top level process that runs the routines of lower level processes
%   to perform calculations on IDL CDF files.
%   
%
%   Error checking is added to check for non-realistic interval values:
%   ones less than the orbit range and ones greater than the orbit range.
%   Error checking is also done on the orbit range making sure that the
%   orbit values exist and that the range make sense (i.e. 5704-5500 ->
%   5500-5704)
%
%   1/21/2011 - Creation of original functionality to plot orbital data.
%               MODE 'orbitrange'.
%
%   2/1/2011 - Added error checking for MODE 'statistics' and various optimizations.
%
%   2/5/2011 - Added noise floor calculations. MODE 'noisefloor'.
%
%   2/12/2011 - Added radar comparison section. MODE 'radar'.
%
%   2/17/2011 - Changed for legibility and addition of MODE 'polarplot'
%   
%
%
%% INPUT
%   
%   orbitrange - String range of orbits to be processed or individual orbit to
%   process. Further revisions may include the capability to select
%   multiple individual orbits at a time.
%   
%   interval - This will specify the interval between the min and the max
%   orbits to process
%   
%   option - saves data in the indicated global variable folder
%                   'plots' - will save just the plots (limited to
%                   certain mode)
%                   'savedata' - will save just the data (limited to
%                   certain mode)
%                   'saveall' - will save both plots and data (limited to
%                   certain mode)
%
%%   MODE 'orbitrange':
%   
%   EX.  process_orbit('orbitrange','5716-7000',1, 'option')
%           ^              ^             ^      ^         ^
%           |              |             |      |         |
%       Function call    mode       orbit   interval  optional parameters
%
%   The function will parse the string to process orbit 5716-7000. Has the
%   capability to do singular orbits as well as multiple orbits.
%
%   'option' - 'plots', 'savedata', 'saveall'
%
%
%%   MODE 'statistics':
%
%   CALLING:  process_orbit('statistics', time,lat,long,alt,dtime,dlat,dlong,dalt, 'option')
%
%   Inputs:
%
%       Time - start time of the statistical analysis. (Unix time(Seconds))
%       Lat  - lower bound of latitude to bin. (In Degrees: -90 to 90)
%       Long - lower bound of longitude to bin. (In Degrees: -180 to 180)
%       Alt  - lower bound of altitude to bin.  (In kilometers)
%       Dtime - end time of the statistical analysis. (Unix time(Seconds))
%       Dlat  - upper bound of latitude to bin. (in Degrees: -90 to 90)
%       Dlong - upper bound of longitude to bin. (In Degrees: -180 to 180)
%       Dalt - upper bound of altitude to bin. (In kilometers)
%
%   EX:
%       process_orbit(8.612e8, 41.4, 30.4, 1000, 8.614e8, 80.4, 54.3, 1500)
%
%  This function will pass the input arguments into a sub-function that
%  will do all the necessary processing. The name of this sub-function is
%  called orbit_stats. The result will be a histograph showing all data
%  within the timeframe, latitude frame, longitude frame, and altitude
%  frame.
%   
%  'option' - 'plots'
%
%%   MODE 'noisefloor':
%   
%   EX.  process_orbit('noisefloor',  '5716-9000',   1, 'option')
%           ^              ^             ^      ^         ^
%           |              |             |      |         |
%       Function call    mode     orbit range  interval  optional parameters
%
%   The function will parse the string to process orbit 5716-9000.
%   Creating binned versions of theta and graphing the noisefloor of a
%   given range.
%
%  'option' - 'plots', 'savedata', 'saveall'
%   NOTE: 'savedata' and 'saveall' are necessary for calculating final
%   rms e-field

%%   MODE 'radar':
%   
%   EX.  process_orbit('radar',  '5716-9000',   1, 'option')
%           ^              ^             ^      ^         ^
%           |              |             |      |         |
%       Function call    mode     orbit range  interval  optional parameters
%
%   The function will parse the string to process orbit 5716-9000.
%   Checks against ILAT for satellite crossings within the radar spatial
%   range.
%
% 'option'- none needed

%%   MODE 'polarplot':
%
%   CALLING:
%   process_orbit('polarplot',orbitrange,mlt,mlat,alt,kp_index, 'option')
%
%   Inputs:
%       
%       orbitrange - String range of orbits to be processed or individual orbit to
%           process. Further revisions may include the capability to select
%           multiple individual orbits at a time.
%       mlt - String range of MLT (Magnetic Local Time) to plot must go
%       from lowest to highest value
%       mlat - String range of MLAT (Magnetic Latitude) mapped to 100km
%       must go from lowest to highest in degrees(-90-90 degrees)
%       alt - String range of ALT (range from 350-4175km)
%       ap_index - String range of ap_index to plot (0-400)
%
%   This function will create a 3d polar intensity plot of the Poyntning
%   flux over a given MLT range and MLAT range.
%
%   'option' - 'plots'
%
%% OPTIONAL INPUT:
%
%   EX.  
%       process_orbit('orbitrange','5716-5718',1,'plots')
%
%       'plots' - will save the plot figures in the output directory
%       'savedata' - will save the data from the plots without saving the
%       plots
%       'saveall' - saves both the plots and the data in the output
%       directory
%
%   EX.
%       process_orbit('statistics', 8.612e8, 41.4, 30.4, 1000, 8.614e8, 80.4, 54.3, 1500, 'plots')
%       
%       'plots' - will save the plot figures in the output directory
%        NOTE: Fairly time consuming
%       'savedata' - will save the data from the plots without saving the
%       plots
%       'saveall' - saves both the plots and the data in the output
%       directory
%
%       NOTE: For mode 'statistics' the final resulting matrix that is
%       created is save separately.
%
%   EX.
%       process_orbit('noisefloor',  '5716-9000',   1, 'saveall')
%       
%       'savedata' - will save the data from the plots without saving the
%       plots
%       'saveall' - saves both the plots and the data in the output
%       directory. (NEEDS TO BE DONE) NOTE: Fairly time consuming
%
%
%
%   EX.
%       process_orbit('radar',  '5716-9000',   1)
%       
%
%   EX.
%       process_orbit('polarplot',  '5716-9000',   1, 'plots')
%       
%       'plots' - only this mode is currently implemented
%
%
%       NOTE: For mode 'statistics' the final resulting matrix that is
%       created is save separately.
%% OUTPUT
%
%   None.
%
%
%% REVISION
%
%   1.0:
%       Functionality of obtaining orbits and saving orbit data. (1/21/11)
%   1.1:
%       Functionality to extract data from subplots. (1/24/11)
%   1.2:    
%       Added clearing of plots for sequential plotting, so memory will not
%       explode. (1/24/11)
%
%   1.3:
%       Optimization and modification of top level function to accept
%       different parameters. ADDITION OF MODE 'statistics'!! 
%   
%   1.4:
%       Added error checking for MODE 'statistics'.
%
%   1.5:
%       Added OPTION functionality.
%
%   1.6:
%       Added checking for validity of orbit time spans.
%
%   1.7:
%       Changed functionality of process_orbit so that it will be flexible
%       for inclusions of new modes.
%   
%   1.8:
%       Fixed bugs with code and various optimizations in coding structure.
%
%
%   1.9:
%       Inclusion of functionality for EES and IES data.
%
%   2.0:
%       Added functionality for new function 'polarplot'.
%   
%   2.1:
%       Fixed comments and coding structure.
%**************************************************************************
%**************************************************************************
%%
    fastdata = 'F:\FastData\'; % Where the FAST data is stored
    processeddata = 'F:\ProcessedData\'; % Where the processed data is outputted
    tmp_directory = 'C:\Documents and Settings\vanwelie\Desktop\TempStatsData\'; %temporary directory for data processing
    radar_directory = 'F:\ProcessedData\RadarData\'; % where the radar_directory will be exported to
    orbitbin_directory = 'F:\ProcessedData\orbitbin_directory\'; %where the orbit bins needed for noise floor calculation
    massbin_directory = 'F:\ProcessedData\massbin_directory\'; %where the orbit bins needed for noise floor calculation
    
%   ********************IMPORTANT*******************
%   ************************************************
%   The above variables need to point exactly to the directory which all the
%   fast data is currently being stored and where the processed data will
%   be exported.




    %%   Global variables needed for sub-functions
    %   Put here if needed...
    global valid_range_flag; 
    valid_range_flag = 0;   %set intial value to 0 to indicate the time range has not been found
    
    global min_max_vals
    
    %column 1 is min, column 2 is max
    %set by Megan van Welie ... there is probably a better solution for
    %instantialization of variables
    tmp_min_max = [999999 -999999];
    min_max_vals = struct('orb_lat', tmp_min_max, ...
                            'orb_lng', tmp_min_max, ...
                            'orb_alt', tmp_min_max, ...
                            'e_av_x', tmp_min_max, ...
                            'e_av_y', tmp_min_max, ...
                            'e_av_z', tmp_min_max, ...
                            'e_nb_x', tmp_min_max, ...
                            'e_nb_y', tmp_min_max, ...
                            'e_nb_z', tmp_min_max, ...
                            'e_lat', tmp_min_max, ...
                            'e_lng', tmp_min_max, ...
                            'e_alt', tmp_min_max, ...
                            'db_x', tmp_min_max, ...
                            'db_y', tmp_min_max, ...
                            'db_z', tmp_min_max, ...
                            'b_x', tmp_min_max, ...
                            'b_y', tmp_min_max, ...
                            'b_z', tmp_min_max, ...
                            'mag_lat', tmp_min_max, ...
                            'mag_lng', tmp_min_max, ...
                            'mag_alt', tmp_min_max);
    clearvars tmp_min_max
    
    %%   Declare variable space for option
    option = [];
    
    %%   Create a log of the output
    delete('C:\process_orbit_log.txt'); %deletes the previous log
    diary('C:\process_orbit_log.txt');
    
    %%   Check number of input arguments. Mainly for debug mode and for
    %   information
    cprintf('blue','Number of inputs = %d\n', nargin);
    mode = lower(mode);
    cprintf('blue','Mode = %s\n',mode);
    optargin = size(varargin,2);
    cprintf('blue','Number of input arguments: %d\n',optargin);

    for i=1:optargin
        if(isnumeric(varargin{i}))
        cprintf('blue',['Input ', int2str(i), ': %d\n'],varargin{i});
        else
        cprintf('blue',['Input ', int2str(i), ': %s\n'],varargin{i});
        end
    end

%% ERROR CHECKING
    %  Check for which mode is currently active. The reason for separating
    %  each mode into a modular design is for further capability to add more
    %  functions in future revisions without the need to alter previous
    %  code. Even if there may be code repeated, it can be altered without
    %  affecting other functions.
    switch mode
        %%**********************************************************************
        %%********************** ORBITRANGE ERROR CHECKING *********************
        %%**********************************************************************
        
        case {'orbitrange'} 
            %   Check for the right number of arguments given the mode
            %   selected
            if(optargin ~= 2 && optargin ~=3)
                cprintf('red','Invalid number of input arguments\n');
                cprintf('red','Correct calling procedure is:\n\n');
                cprintf('red','process_orbit(''orbit'' or ''orbitrange'',''orbitrange'',interval)\n\n');
                cprintf('red','Please refer to the function process_orbit.m for more information...\n');
                return
            end
            
            %   Set the variables of the input to orbitrange and interval
            %   respectively to do checking
            orbitrange = varargin{1};
            interval = varargin{2};

            %   Check if an option is enabled
            if(optargin == 3)
                if(strcmp(varargin{3}, 'plots')...
                        || strcmp(varargin{3}, 'savedata')...
                        || strcmp(varargin{3}, 'saveall'))
                    option = varargin{3};
                else
                    cprintf('red','Invalid OPTION parameter\n');
                    return
                end
            end

                %   Find the range of intervals. Do error checking to make sure
                %   that the input arguments are valid else return
                k = strfind(orbitrange, '-');
                if (~isempty(k))
                    orbitLow = str2double(orbitrange(1:k-1));
                    orbitHigh = str2double(orbitrange(k+1:length(orbitrange)));
                    if(isempty(orbitLow) || isempty(orbitHigh))
                        cprintf('red','Not valid orbit. Quitting...\n');
                        return
                    elseif(isnan(orbitHigh) || isnan(orbitLow))
                        cprintf('red','NaN value for orbits... Invalid orbit input.\n');
                        return                   
                    elseif(orbitHigh <= 0 || orbitLow <= 0)
                        cprintf('red', 'Negative orbit value...\n');
                        return   
                    elseif(orbitLow > orbitHigh) 
                        %   Switches ordering of orbits if orbitLow > orbitHigh
                        tmp = orbitLow;
                        orbitLow = orbitHigh;
                        orbitHigh = tmp;
                    end
                else
                    %   Set it to be one single orbit and do error checking
                    %   again
                    singleorbit = str2double(orbitrange);

                    if(isempty(singleorbit))
                        cprintf('red','Not valid orbit. Quitting...\n');
                        return
                    elseif(isnan(singleorbit))
                        cprintf('red','NaN value for orbit... Invalid orbit input.\n');
                        return                    
                    elseif(singleorbit <= 0)
                        cprintf('red', 'Negative orbit value...\n');
                        return
                    end
                    orbitLow = singleorbit;
                    orbitHigh = singleorbit;
                end

            %   Do some sort of error checking of interval
            if(interval <= 0 || (interval > (orbitHigh-orbitLow+1)...
                    && (~strcmp(mode,'orbitrange') || ~strcmp(mode,'axis'))))
                cprintf('red','Not valid interval. Quitting...\n');
                return
            end

            %   Checks if the interval is not a common denominator of
            %   orbitHigh-orbitLow
            if(mod((orbitHigh-orbitLow+1), interval) ~= 0)
                reply = input('The last value(s) may not be processed due to the interval size. Continue anyway? (y/n) ', 's');
                if isempty(reply)
                    %   Assume return character means yes.
                    reply = 'y';
                end
                if (strcmp(reply, 'n'))
                    cprintf('red','Quitting from function and returning to MATLAB.\n');
                    return
                end
                cprintf('comment','Continuing to process...\n');
            end
            
        %******************************************************************
        %********************** STATISTICS ERROR CHECKING *****************
        %******************************************************************
        case{'statistics'}
            if(optargin ~=8 && optargin ~=9)
                cprintf('red','Invalid number of input arguments\n');
                cprintf('red','Correct calling procedure is :\n\n');
                cprintf('red','process_orbit(''statistics'',time,lat,long,alt,dtime,dlat,dlong,dalt)\n\n');
                cprintf('red','Please refer to the function process_orbit.m for more information...\n');
                return
            end
            
            %   Make sure that the inputs are numbers
            for i=1:8
                if(~isnumeric(varargin{i}))
                    cprintf('red','Invalid input parameters - not numbers\n');
                    return
                end
            end


            %   Set the variables to their respective names
            time  = varargin{1};
            lat   = varargin{2};
            long  = varargin{3};
            alt   = varargin{4};
            dtime = varargin{5};
            dlat  = varargin{6};
            dlong = varargin{7};
            dalt  = varargin{8};

            %   Check to make sure that the parameters meet the requirements:
            %   dtime > time, dlat > lat ... Very long IF statement >_>
            if(dtime > time && ((dlat <= 90 && lat >= -90)...
                    && dlat > lat) && ((dlong <= 180 && long >= -180)...
                    && dlong > long) && ((dalt <= 4175 && alt >= 350)...
                    && dalt > alt))

                %   Valid after this point
                %   Check for whether or not the option was enabled or disabled.

                if(optargin == 9)
                    if(strcmp(varargin{9}, 'plots') ...
                            || strcmp(varargin{9}, 'savedata') ...
                            || strcmp(varargin{9}, 'saveall'))
                        option = varargin{9};
                    else
                        cprintf('red','Invalid OPTION parameter');
                        return
                    end
                end

            %   Searches the first and last folder in the directory and uses those
            %   numbers for the range

            %   Assume that the orbits are in ordered format in the directory
            %   listing

            %   Calls a binary search algorithm function that will scan through
            %   the directory to look for the orbit

            orbitNum= search_orbit(fastdata, time, dtime);
            orbitLow = orbitNum;

            dir_listing = dir(fastdata);    %   Gets a listing of the directories

            orbitHigh = str2double(dir_listing(end).name(length(dir_listing(end).name )- 4:end));
            interval = 1;

            else
                cprintf('red','Failed upon checking validity of input parameters...\n');
                return
            end
            
        %%**********************************************************************
        %%********************** NOISEFLOOR ERROR CHECKING *********************
        %%**********************************************************************           
        case{'noisefloor'}
            if(optargin ~= 2&& optargin ~=3)
                cprintf('red','Invalid number of input arguments\n');
                cprintf('red','Correct calling procedure is :\n\n');
                cprintf('red','process_orbit(''axis'',''orbitrange'',interval)\n\n');
                cprintf('red','Please refer to the function process_orbit.m for more information...\n');
                return
            end
            %   Set the variables of the input to orbitrange and interval
            %   respectively to do checking
            orbitrange = varargin{1};
            interval = varargin{2};

            %   Check if an option
            if(optargin == 3)
                if(strcmp(varargin{3}, 'plots')...
                        || strcmp(varargin{3}, 'savedata')...
                        || strcmp(varargin{3}, 'saveall'))
                    option = varargin{3};
                else
                    cprintf('red','Invalid OPTION parameter\n');
                    return
                end
            end

                %   Find the range of intervals. Do error checking to make sure
                %   that the input arguments are valid else return
                k = strfind(orbitrange, '-');
                if (~isempty(k))
                    orbitLow = str2double(orbitrange(1:k-1));
                    orbitHigh = str2double(orbitrange(k+1:length(orbitrange)));
                    if(isempty(orbitLow) || isempty(orbitHigh))
                        cprintf('red','Not valid orbit. Quitting...\n');
                        return
                    elseif(isnan(orbitHigh) || isnan(orbitLow))
                        cprintf('red','NaN value for orbits... Invalid orbit input.\n');
                        return
                    elseif(orbitHigh <= 0 || orbitLow <= 0)
                        cprintf('red', 'Negative orbit values...\n');
                        return
                    elseif(orbitLow > orbitHigh) 
                        %   Switches ordering of orbits if orbitLow > orbitHigh
                        tmp = orbitLow;
                        orbitLow = orbitHigh;
                        orbitHigh = tmp;
                    end
                else
                    %   Set it to be one single orbit and do error checking
                    %   again
                    singleorbit = str2double(orbitrange);

                    if(isempty(singleorbit))
                        cprintf('red','Not valid orbit. Quitting...\n');
                        return
                    elseif(isnan(singleorbit))
                        cprintf('red','NaN value for orbit... Invalid orbit input.\n');
                        return
                    elseif(singleorbit <= 0)
                        cprintf('red', 'Negative orbit value...\n');
                        return
                    end
                    orbitLow = singleorbit;
                    orbitHigh = singleorbit;
                end

            %   Do some sort of error checking of interval
            if(interval <= 0 || (interval > (orbitHigh-orbitLow+1)...
                    && (~strcmp(mode,'orbitrange') || ~strcmp(mode,'axis'))))
                cprintf('red','Not valid interval. Quitting...\n');
                return
            end

            %   Checks if the interval is not a common denominator of
            %   orbitHigh-orbitLow
            if(mod((orbitHigh-orbitLow+1), interval) ~= 0)
                reply = input('The last value(s) may not be processed due to the interval size. Continue anyway? (y/n) ', 's');
                if isempty(reply)
                    %   Assume return character means yes.
                    reply = 'y';
                end
                if (strcmp(reply, 'n'))
                    cprintf('red','Quitting from function and returning to MATLAB.\n');
                    return
                end
                cprintf('comment','Continuing to process...\n');
            end
            
        %%**********************************************************************
        %%***************************** RADAR*****************************
        %%**********************************************************************
        
        case {'radar'} 
            %   Check for the right number of arguments given the mode
            %   selected
            if(optargin ~= 2 && optargin ~=3)
                cprintf('red','Invalid number of input arguments\n');
                cprintf('red','Correct calling procedure is:\n\n');
                cprintf('red','process_orbit(''orbit'' or ''orbitrange'',''orbitrange'',interval)\n\n');
                cprintf('red','Please refer to the function process_orbit.m for more information...\n');
                return
            end
            
            %   Set the variables of the input to orbitrange and interval
            %   respectively to do checking
            orbitrange = varargin{1};
            interval = varargin{2};

            %   Check if an option is enabled
            if(optargin == 3)
                if(strcmp(varargin{3}, 'plots')...
                        || strcmp(varargin{3}, 'savedata')...
                        || strcmp(varargin{3}, 'saveall'))
                    option = varargin{3};
                else
                    cprintf('red','Invalid OPTION parameter\n');
                    return
                end
            end

                %   Find the range of intervals. Do error checking to make sure
                %   that the input arguments are valid else return
                k = strfind(orbitrange, '-');
                if (~isempty(k))
                    orbitLow = str2double(orbitrange(1:k-1));
                    orbitHigh = str2double(orbitrange(k+1:length(orbitrange)));
                    if(isempty(orbitLow) || isempty(orbitHigh))
                        cprintf('red','Not valid orbit. Quitting...\n');
                        return
                    elseif(isnan(orbitHigh) || isnan(orbitLow))
                        cprintf('red','NaN value for orbits... Invalid orbit input.\n');
                        return                   
                    elseif(orbitHigh <= 0 || orbitLow <= 0)
                        cprintf('red', 'Negative orbit value...\n');
                        return   
                    elseif(orbitLow > orbitHigh) 
                        %   Switches ordering of orbits if orbitLow > orbitHigh
                        tmp = orbitLow;
                        orbitLow = orbitHigh;
                        orbitHigh = tmp;
                    end
                else
                    %   Set it to be one single orbit and do error checking
                    %   again
                    singleorbit = str2double(orbitrange);

                    if(isempty(singleorbit))
                        cprintf('red','Not valid orbit. Quitting...\n');
                        return
                    elseif(isnan(singleorbit))
                        cprintf('red','NaN value for orbit... Invalid orbit input.\n');
                        return                    
                    elseif(singleorbit <= 0)
                        cprintf('red', 'Negative orbit value...\n');
                        return
                    end
                    orbitLow = singleorbit;
                    orbitHigh = singleorbit;
                end

            %   Do some sort of error checking of interval
            if(interval <= 0 || (interval > (orbitHigh-orbitLow+1)...
                    && (~strcmp(mode,'orbitrange') || ~strcmp(mode,'axis'))))
                cprintf('red','Not valid interval. Quitting...\n');
                return
            end

            %   Checks if the interval is not a common denominator of
            %   orbitHigh-orbitLow
            if(mod((orbitHigh-orbitLow+1), interval) ~= 0)
                reply = input('The last value(s) may not be processed due to the interval size. Continue anyway? (y/n) ', 's');
                if isempty(reply)
                    %   Assume return character means yes.
                    reply = 'y';
                end
                if (strcmp(reply, 'n'))
                    cprintf('red','Quitting from function and returning to MATLAB.\n');
                    return
                end
                cprintf('comment','Continuing to process...\n');
            end
            
        %******************************************************************
        %********************** POLARPLOT ERROR CHECKING *****************
        %******************************************************************
        case{'polarplot'}
            if(optargin ~=5 && optargin ~=6)
                cprintf('red','Invalid number of input arguments\n');
                cprintf('red','Correct calling procedure is :\n\n');
                cprintf('red','process_orbit(''statistics'',time,lat,long,alt,dtime,dlat,dlong,dalt)\n\n');
                cprintf('red','Please refer to the function process_orbit.m for more information...\n');
                return
            end
            
            %   Make sure that the inputs are strings
            for i=1:5
                if(~ischar(varargin{i}))
                    cprintf('red','Invalid input parameters - not strings\n');
                    return
                end
            end
            
            %   Start operations to get the data ranges from the strings
            %   into variables. orbitrange,mlt,mlat,alt,kp_index
            
            orbitrange  = varargin{1};
            mlt   = varargin{2};
            mlat  = varargin{3};
            alt   = varargin{4};
            kp_index = varargin{5};
            option = varargin{6};

            %   Find the range of orbit intervals. Do error checking to make sure
            %   that the input arguments are valid else return
                k = strfind(orbitrange, '-');
                if (~isempty(k))
                    orbitLow = str2double(orbitrange(1:k-1));
                    orbitHigh = str2double(orbitrange(k+1:length(orbitrange)));
                    if(isempty(orbitLow) || isempty(orbitHigh))
                        cprintf('red','Not valid orbit. Quitting...\n');
                        return
                    elseif(isnan(orbitHigh) || isnan(orbitLow))
                        cprintf('red','NaN value for orbits... Invalid orbit input.\n');
                        return
                    elseif(orbitLow > orbitHigh) 
                        %   Switches ordering of orbits if orbitLow > orbitHigh
                        tmp = orbitLow;
                        orbitLow = orbitHigh;
                        orbitHigh = tmp;
                    end
                else
                    %   Set it to be one single orbit and do error checking
                    %   again
                    singleorbit = str2double(orbitrange);

                    if(isempty(singleorbit))
                        cprintf('red','Not valid orbit. Quitting...\n');
                        return
                    elseif(isnan(singleorbit))
                        cprintf('red','NaN value for orbit... Invalid orbit input.\n');
                        return
                    elseif(singleorbit <= 0)
                        cprintf('red', 'Negative orbit value...\n');
                        return
                        
                    end
                    orbitLow = singleorbit;
                    orbitHigh = singleorbit;
                end
                
           %    Find the range of mlt values. Do error checking to make
           %    sure that the input arguments are valid
                k = strfind(mlt, '-');
                if (~isempty(k))
                    
                    %   Gets the MLT start time
                    mlt_start = mlt(1:k-1);
                    j = strfind(mlt_start, ':');
                    if(~isempty(j))
                        mlt_start = str2double(mlt_start(1:j-1)) + str2double(mlt_start(j+1:end)) / 60;
                    else
                        cprintf('red','Not valid MLT start time.\n');
                        return
                    end
                    
                    %   Gets the MLT end time
                    mlt_end = mlt(k+1:length(mlt));
                    j = strfind(mlt_end, ':');
                    if(~isempty(j))
                        mlt_end = str2double(mlt_end(1:j-1)) + str2double(mlt_end(j+1:end)) / 60;
                    else
                        cprintf('red','Not valid MLT end time\n');
                        return
                    end
                    if(isempty(mlt_start) || isempty(mlt_end))
                        cprintf('red','Not valid orbit MLT. Quitting...\n');
                        return
                    elseif(isnan(mlt_start) || isnan(mlt_end))
                        cprintf('red','NaN value for MLT... Invalid MLT input.\n');
                        return
                    end
                else
                    cprintf('red', 'Invalid MLT range.\n');
                    return
                end
           
           %    Find the range of mlat values. Do error checking to make 
           %    sure that the input arguments are valid     
                k = strfind(mlat, '-');
                
                %   Cannot have more than three dashes in the input. Since
                %   the MLAT can range from -90-90 degrees we need to
                %   consider from -90 - -1 degrees which this conditional
                %   will check.
                if(length(k) > 3)
                    cprintf('red','Illegal MLAT range.\n');
                else
                    if(length(k) == 3)
                        k = median(k);
                    else
                        if(min(k) == 1)
                            k = max(k);
                        else
                            k = min(k);
                        end
                    end
                end
                
                %   Now do the checking for whether or not the values are
                %   acceptable
                if (~isempty(k))
                    mlat_start = str2double(mlat(1:k-1));
                    mlat_end = str2double(mlat(k+1:length(mlat)));
                    if(isempty(mlat_start) || isempty(mlat_end))
                        cprintf('red','Not valid MLAT. Quitting...\n');
                        return
                    elseif(isnan(mlat_start) || isnan(mlat_end))
                        cprintf('red','NaN value for MLAT... Invalid MLAT input.\n');
                        return
                    elseif(mlat_start > mlat_end) 
                        %   Switches ordering of orbits if orbitLow > orbitHigh
                        tmp = mlat_start;
                        mlat_start = mlat_end;
                        mlat_end = tmp;
                    end
                else
                    cprintf('red', 'Invalid MLAT range.\n');
                    return
                end
            
            %   Find the range of altitude inputs. Do error checking to
            %   make sure that the input arguments are valid
                k = strfind(alt, '-');
                if (~isempty(k))
                    alt_start = str2double(alt(1:k-1));
                    alt_end = str2double(alt(k+1:length(alt)));
                    if(isempty(alt_start) || isempty(alt_end))
                        cprintf('red','Not valid ALT. Quitting...\n');
                        return
                    elseif(isnan(alt_start) || isnan(alt_end))
                        cprintf('red','NaN value for ALT... Invalid ALT input.\n');
                        return
                    elseif(alt_end >= 4375 || alt_start <=300) 
                        cprintf('red','Invalid altitude ranges, must be between 300-4375km.\n');
                        return
                    end
                else
                    cprintf('red', 'Invalid ALT range.\n');
                    return
                end
                
            %   Find the range for kp-index inputs. Do error checking to
            %   make sure that the input arguments are valid.
            
                k = strfind(kp_index, '-');
                if (~isempty(k))
                    kp_index_start = str2double(kp_index(1:k-1));
                    kp_index_end = str2double(kp_index(k+1:length(kp_index)));
                    if(isempty(kp_index_start) || isempty(kp_index_end))
                        cprintf('red','Not valid kp_index. Quitting...\n');
                        return
                    elseif(isnan(kp_index_start) || isnan(kp_index_end))
                        cprintf('red','NaN value for kp_index... Invalid kp_index input.\n');
                        return
                    elseif((kp_index_start < 0 || kp_index_start > 400) || (kp_index_end < 0 || kp_index_end > 400))
                        cprintf('red', 'Nonreal kp_index value...\n');
                        return
                    elseif(kp_index_start > kp_index_end) 
                        %   Switches ordering of kp_index if kp_index_start
                        %   > kp_index_end
                        tmp = kp_index_start;
                        kp_index_start = kp_index_end;
                        kp_index_end = tmp;
                    end
                else
                    %   Set it to be one single orbit and do error checking
                    %   again
                    kp_index = str2double(kp_index);

                    if(isempty(kp_index))
                        cprintf('red','Not valid kp_index. Quitting...\n');
                        return
                    elseif(isnan(kp_index))
                        cprintf('red','NaN value for kp_index... Invalid kp_index input.\n');
                        return
                    elseif((kp_index < 0 || kp_index > 9))
                        cprintf('red', 'Nonreal kp_index value...\n');
                        return
                    end
                    kp_index_start = kp_index;
                    kp_index_end = kp_index;
                end
                
        %******************************************************************
        %******************* OTHERWISE CONDITION***************************
        %******************************************************************
        otherwise
            cprintf('red','Mode ''%s'' is not currently implemented. Type HELP PROCESS_ORBIT for more information on acceptible modes.\n',mode);
            return
    end


%%   Main Function
%   Main part of the function that can save plots and dataMode should have been check by this point


     
%**************************************************************************
%*************************    ORBIT RANGE    ******************************
%**************************************************************************
            switch mode
            case{'orbitrange'}
                for currOrbit=orbitLow:interval:orbitHigh
                    %   Change the format of the values and do some string processing.
                    %   Unless the naming syntax of the orbit change this part should not be
                    %   altered 

                    orbitnum = int2str(currOrbit);

                    %   Gets the string version of an orbit. EX. 5383 ->
                    %   '05383'
                    while(length(orbitnum) ~= 5)
                        orbitnum = strcat('0', orbitnum);
                    end

                    orbitname = strcat('fa_k0_', orbitnum);

                    try 
                        load(strcat(processeddata, '\PoyntingFlux\', orbitname,'\',orbitname,'_geo')); 
                        load(strcat(processeddata,'\PoyntingFlux\', orbitname,'\',orbitname,'_gei'));  
                    catch exception
                        getReport(exception,'basic', 'hyperlinks', 'off');


                        %   Inclusion of reading in EES and IES data, the naming syntax was
                        %   originally created by Berkeley, thus it needed to be modified
                        %   to match the existing file names
                        iesorbitname = strcat('fa_k0_ies_',orbitnum,'_v04.cdf');
                        eesorbitname = strcat('fa_k0_ees_',orbitnum,'_v04.cdf');

                        %   There is probably a better way than this to error catch if the folder
                        %   contains no items

                        directorypath = strcat(fastdata,orbitname, '\');

                        orb_path = strcat(directorypath, orbitname, '_orb.cdf');
                        ef_path = strcat(directorypath, orbitname, '_ef.cdf');
                        db_path = strcat(directorypath, orbitname, '_mag.cdf');
                        sa_path = strcat(directorypath,orbitname, '_sa.cdf');
                        ies_path = strcat(directorypath, iesorbitname);
                        ees_path = strcat(directorypath, eesorbitname);


                        %   Currently each mode has to do individual tracking because the CDF
                        %   files needed might be different for each mode

                        %   Check for the existence of the CDF files
                        if(exist(orb_path, 'file') == 2 ...
                            && exist(ef_path, 'file') == 2 ...
                            && exist(db_path, 'file') == 2 ...
                            && exist(sa_path, 'file') == 2 ...
                            && exist(ies_path, 'file') == 2 ...
                            && exist(ees_path, 'file') == 2)
                            %   Begin reading the CDFs
                        try
                            orb_data = cdfread(orb_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'FA_POSGEI'},{'FA_VELGEI'},{'FA_POS'},{'FA_VEL'},{'ALT'},{'LAT'},{'LNG'},{'ILAT'},{'MLT'},{'B_MODEL'},{'B_FOOT'},{'FOOT_LAT'},{'FOOT_LNG'}]);

                            if(any(cellfun('isempty',orb_data)))
                                cprintf('red', 'Empty set for orb data... Continuing.\n');
                                continue;
                            end

                            %orb_data{:,1}  = UNIX time
                            %orb_data{:,2}  = Pos x,y,z(GEI)
                            %orb_data{:,3}  = Vel x,y,z(GEI)
                            %orb_data{:,4}  = Pos x,y,z(GEO)
                            %orb_data{:,5}  = Vel x,y,z(GEO)
                            %orb_data{:,6}  = Altitude (km) 
                            %orb_data{:,7}  = Latitude (deg)
                            %orb_data{:,8}  = Longitude (deg)
                            %orb_data{:,9}  = Invariant Latitude (deg)
                            %orb_data{:,10} = Magnetic Local Time
                            %orb_data{:,11} = B Model x,y,z (GEI)
                            %orb_data{:,12} = B Footprint (mapped to 100 km)
                            %orb_data{:,13} = Latitude Footprint (geodectic)
                            %orb_data{:,14} = Longitude Footprint (geodectic)

                            ef_data = cdfread(ef_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'E_NEAR_B'},{'E_ALONG_V'}]);
                            if(any(cellfun('isempty',ef_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                            end
                            %ef_data{:,1}   = UNIX time
                            %ef_data{:,2}   = E near B (E_z (DCS))
                            %ef_data{:,3}   = E along V (E_x (DCS))

                            mag_data = cdfread(db_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'DB_GEI_O'},{'DB_GEI_E'},{'DB_GEI_B'},{'B_GEI_O'},{'B_GEI_E'},{'B_GEI_B'},{'DB_FAC_V_O'},{'DB_FAC_V_E'},{'DB_FAC_V_B'}]);
                            if(any(cellfun('isempty',mag_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                            end
                            %mag_data{:,1}    = UNIX time
                            %mag_data{:,2:4}  = Delta-B x,y,z (GEI)
                            %mag_data{:,5:7}  = Total B x,y,z (GEI)
                            %mag_data{:,8:10} = Delta-B (FAC_V)

                            sa_data = cdfread(sa_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'}, {'FA_SPIN_RA'}, {'FA_SPIN_DEC'}]);
                            if(any(cellfun('isempty',sa_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                            end
                            %sa_data{:,1}   = UNIX time
                            %sa_data{:,2}   = Right Ascenscion Angle (deg)
                            %sa_data{:,3}   = Declination Angle (deg)

                            ees_data = cdfread(ees_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'JEe'}]);
                            if(any(cellfun('isempty',ees_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                            end
                            %ees_data{:,1}   = UNIX time
                            %ees_data{:,2}   = Kinetic Energy Flux(Electron)(W/m^2)                    

                            ies_data = cdfread(ies_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'JEi'}]);
                            if(any(cellfun('isempty',ies_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                            end
                            %ies_data{:,1}   = UNIX time
                            %ies_data{:,2}   = Kinetic Energy Flux(Ion)(W/m^2)  

                        catch exception
                            fprintf([getReport(exception,'basic', 'hyperlinks', 'off') '\n']);
                            cprintf('red', 'Unable to read the right data values from CDF for orbit %d.\n', currOrbit);
                            continue
                        end

                        orb_time = uint32(orb_data{:,1});
                        ef_time = uint32(ef_data{:,1});
                        db_time = uint32(mag_data{:,1});
                        sa_time = uint32(sa_data{:,1});
                        ees_time = uint32(ees_data{:,1});
                        ies_time = uint32(ies_data{:,1});

                        end_times = [orb_time(end), sa_time(end)];
                        start_times = [orb_time(1), sa_time(1)];

                        %   The electric field data must fit within the minimum
                        %   of the end times and the maximum of the start times
                        %   for this to be valid
                        if((db_time(end) >= orb_time(1) ...
                            && db_time(1) <= orb_time(end)) ...
                            && (sa_time(end) >= orb_time(1) ...
                            && sa_time(1) <=orb_time(end)))
                                if((ef_time(1) >= max(start_times) ...
                                    && ef_time(end) <= min(end_times))  ...
                                    && (ees_time(1) >= max(start_times) ...
                                    && ees_time(end) <= min(end_times)) ...
                                    && (ies_time(1) >= max(start_times) ...
                                    && ies_time(end) <= min(end_times)))
                                valid_timespan = true;
                                else
                                    valid_timespan = false;
                                end
                        else
                            valid_timespan = false;
                        end

                            if (valid_timespan == true)

                                cprintf('comment','Beginning to process orbit: %d\n', currOrbit);

                                %   Begin timer
                                tic;

                                [output_data_gei output_data_geo] = process_flux(orb_data, ef_data, mag_data, ees_data, ies_data, sa_data, orbitname, processeddata);

                                cprintf('comment','Processing for Orbit %d took: %f seconds\n',i,toc);
                            else
                                cprintf('red','Not valid orbit timespans for orbit: %d.\n', currOrbit);   
                            end
                        else
                            cprintf('red','Could not find CDF files or preprocessed data for orbit: %d\n', currOrbit)        
                        end
                    end


                    if(~isempty(output_data_gei) && ~isempty(output_data_geo))
                        plot_individual_orbits(output_data_gei, output_data_geo, currOrbit);

                        if(~isempty(option))
                            %   After processing data save the files to the output directory
                            outputdirectory = strcat(processeddata,'SingleOrbitPlots\',orbitname);

                            %   Makes the directory to put the files in
                            mkdir(outputdirectory);

                            %   Goes through the plots and saves them as MATLAB figures also
                            %   saves the data for each of the plots into a cdf file with a
                            %   corresponding name

                            for j = 1:gcf
                                %   Concatenates strings to point to the correct output
                                %   path

                                fileplot = strcat('plot', int2str(j), '.fig');
                                outputplotpath = strcat(outputdirectory, '\', fileplot);
                                if(strcmp(option, 'plots') || strcmp(option,'saveall'))
                                    saveas(j, outputplotpath);
                                end
                                filedata = strcat('plot', int2str(j));
                                outputdatapath = strcat(outputdirectory,'\', filedata);

                                hFig = get(gcf);
                                hAxes = hFig.Children;

                                %   Checks to see if there are multiple plots on the figure
                                %   if grab the subplot data and store them

                                if((strcmp(option, 'savedata') || strcmp(option,'saveall')))
                                    if(length(hAxes)>1)
                                    %   Non-efficient
                                       %hLines = [];

                                    %   Preallocate memory for the plots that have subplots
                                        hLines = zeros(1,length(hAxes));
                                        for k = 1:length(hAxes)
                                            hLines(k) = get(hAxes(length(hAxes) + 1 - k), 'Children');
                                        end
                                        xtmp = cell2mat(get(hLines, 'XData'));
                                        ytmp = cell2mat(get(hLines,'YData'));
                                        cdfwrite(outputdatapath, {'X',xtmp,'Y',ytmp});
                                    %   Else goes and stores the single plot data
                                    else
                                        plottmp = findobj(j, 'Type', 'line');
                                        xtmp = get(plottmp, 'Xdata');
                                        ytmp = get(plottmp, 'Ydata');
                                        cdfwrite(outputdatapath, {'X',xtmp,'Y',ytmp});
                                    end
                                end
                            end
                            %   Clean up plots to speed up later processes
                            close all
                        end
                    end 
                end

%**************************************************************************
%****************************  STATISTICS    ******************************
%**************************************************************************

            case{'statistics'}
                 mkdir(strcat(tmp_directory,'orb'));
                 mkdir(strcat(tmp_directory,'ef'));
                 mkdir(strcat(tmp_directory,'mag'));
                for currOrbit=orbitLow:interval:orbitHigh
                %   Change the format of the values and do some string processing.
                %   Unless the naming syntax of the orbit change this part should not be
                %   altered 

                    orbitnum = int2str(currOrbit);

                    %   Gets the string version of an orbit. EX.
                    %   5383->'05383'
                    while(length(orbitnum) ~= 5)
                        orbitnum = strcat('0', orbitnum);
                    end

                    orbitname = strcat('fa_k0_', orbitnum);

                    %   Inclusion of reading in EES and IES data, the naming syntax was
                    %   originally created by Berkeley, thus it needed to be modified
                    %   to match the existing file names
                    iesorbitname = strcat('fa_k0_ies_',orbitnum,'_v04.cdf');
                    eesorbitname = strcat('fa_k0_ees_',orbitnum,'_v04.cdf');

                %   There is probably a better way than this to error catch if the folder
                %   contains no items

                    directorypath = strcat(fastdata,orbitname, '\');

                    orb_path = strcat(directorypath, orbitname, '_orb.cdf');
                    ef_path = strcat(directorypath, orbitname, '_ef.cdf');
                    db_path = strcat(directorypath, orbitname, '_mag.cdf');
                    sa_path = strcat(directorypath,orbitname, '_sa.cdf');
                    ies_path = strcat(directorypath, iesorbitname);
                    ees_path = strcat(directorypath, eesorbitname);


                %   Currently the each mode has to do individual tracking because the CDF
                %   files needed might be different for each mode

                %   Check for the existence of the CDF files
                    if( exist(orb_path, 'file') == 2 ...
                            && exist(ef_path, 'file') == 2 ...
                            && exist(db_path, 'file') == 2 ...
                            && exist(sa_path, 'file') == 2 ...
                            && exist(ies_path, 'file') == 2 ...
                            && exist(ees_path, 'file') == 2)
                        %   Begin reading the CDFs
                        try
                        orb_data = cdfread(orb_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'FA_POSGEI'},{'FA_VELGEI'},{'FA_POS'},{'FA_VEL'},{'ALT'},{'LAT'},{'LNG'},{'ILAT'},{'MLT'},{'B_MODEL'},{'B_FOOT'},{'FOOT_LAT'},{'FOOT_LNG'}]);
                        if(any(cellfun('isempty',orb_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %orb_data{:,1}  = UNIX time
                        %orb_data{:,2}  = Pos x,y,z(GEI)
                        %orb_data{:,3}  = Vel x,y,z(GEI)
                        %orb_data{:,4}  = Pos x,y,z(GEO)
                        %orb_data{:,5}  = Vel x,y,z(GEO)
                        %orb_data{:,6}  = Altitude (km) 
                        %orb_data{:,7}  = Latitude (deg)
                        %orb_data{:,8}  = Longitude (deg)
                        %orb_data{:,9}  = Invariant Latitude (deg)
                        %orb_data{:,10} = Magnetic Local Time
                        %orb_data{:,11} = B Model x,y,z (GEI)
                        %orb_data{:,12} = B Footprint (mapped to 100 km)
                        %orb_data{:,13} = Latitude Footprint (geodectic)
                        %orb_data{:,14} = Longitude Footpring (geodectic)

                        ef_data = cdfread(ef_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'E_NEAR_B'},{'E_ALONG_V'}]);
                        if(any(cellfun('isempty',ef_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %ef_data{:,1}   = UNIX time
                        %ef_data{:,2}   = E near B (E_z (DCS))
                        %ef_data{:,3}   = E along V (E_x (DCS))

                        mag_data = cdfread(db_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'DB_GEI_O'},{'DB_GEI_E'},{'DB_GEI_B'},{'B_GEI_O'},{'B_GEI_E'},{'B_GEI_B'},{'DB_FAC_V_O'},{'DB_FAC_V_E'},{'DB_FAC_V_B'}]);
                        if(any(cellfun('isempty',mag_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %mag_data{:,1}    = UNIX time
                        %mag_data{:,2:4}  = Delta-B x,y,z (GEI)
                        %mag_data{:,5:7}  = Total B x,y,z (GEI)
                        %mag_data{:,8:10} = Delta-B (FAC_V)

                        sa_data = cdfread(sa_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'}, {'FA_SPIN_RA'}, {'FA_SPIN_DEC'}]);
                        if(any(cellfun('isempty',sa_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %sa_data{:,1}   = UNIX time
                        %sa_data{:,2}   = Right Asenscion Angle (deg)
                        %sa_data{:,3}   = Declination Angle (deg)

                        ees_data = cdfread(ees_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'JEe'}]);
                        if(any(cellfun('isempty',ees_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %ees_data{:,1}   = UNIX time
                        %ees_data{:,2}   = Kinetic Energy Flux(Electron)(W/m^2)                    

                        ies_data = cdfread(ies_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'JEi'}]);
                        %ies_data{:,1}   = UNIX time
                        %ies_data{:,2}   = Kinetic Energy Flux(Ion)(W/m^2)     
                        
                        if(any(cellfun('isempty',ies_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end      
                        catch exception
                            fprintf([getReport(exception,'basic', 'hyperlinks', 'off') '\n']);
                            cprintf('red', 'Unable to read the right data values from CDF for orbit %d.\n', currOrbit);
                            continue
                        end
                        %   Check if the data is valid -- Has the correct start and end
                        %   times by comparing the UNIX times

                        orb_time = uint32(orb_data{:,1});
                        ef_time = uint32(ef_data{:,1});
                        db_time = uint32(mag_data{:,1});
                        sa_time = uint32(sa_data{:,1});
                        ees_time = uint32(ees_data{:,1});
                        ies_time = uint32(ies_data{:,1});

                        end_times = [orb_time(end), sa_time(end) ];
                        start_times = [orb_time(1), sa_time(1)];

                        %   The electric field data must fit within the minimum
                        %   of the end times and the maximum of the start times
                        %   for this to be valid
                        if((db_time(end) >= orb_time(1) ...
                                && db_time(1) <= orb_time(end)) ...
                                && (sa_time(end) >= orb_time(1) ...
                                && sa_time(1) <=orb_time(end)))
                            if((ef_time(1) >= max(start_times) ...
                                    && ef_time(end) <= min(end_times)) ...
                                    && (ees_time(1) >= max(start_times) ...
                                    && ees_time(end) <= min(end_times)) ...
                                    && (ies_time(1) >= max(start_times) ...
                                    && ies_time(end) <= min(end_times)))
                                valid_timespan = true;
                            else
                                valid_timespan = false;
                            end
                        else
                            valid_timespan = false;
                        end

                        if (valid_timespan == true)
                            %   Function calls to be done
                            %   ************************************
                            %   INSERT PROCESSES YOU WANT TO EXECUTE


                            %   Begin timer


                            % Function call for statistics processing

                            if(valid_range_flag == 0 || valid_range_flag ==1)
                                cprintf('comment','Beginning to process orbit: %d\n', currOrbit);
                                tic;
                                [checked_orb, checked_ef, checked_mag] = orbit_stats(orb_data,ef_data,mag_data,time,lat,long,alt,dtime,dlat,dlong,dalt);
                                if(valid_range_flag == 0)
                                    cprintf('comment','Processing for Orbit %d took: %f seconds\n',currOrbit,toc);
                                    continue;
                                elseif(valid_range_flag == 1)
                                    limit_check(checked_orb, checked_ef, checked_mag, tmp_directory, orbitname);
                                    clearvars checked_orb checked_ef checked_mag
                                elseif(valid_range_flag == 2)
                                    cprintf('comment', 'Finished processing orbits... Creating Histographs\n');
                                    orbit_stats_plots(time,lat,long,alt,dtime,dlat,dlong,dalt, tmp_directory);
                                else
                                    cprintf('red','Latitude, longitude, or altitude range not valid for given time range\n');
                                end
                            else
                                break;
                            end   


                            %   Enter Function for processing spin axis

                            cprintf('comment','Processing for Orbit %d took: %f seconds\n',currOrbit,toc);
                            %   ************************************

                            if(valid_range_flag ==2)
                                %   Save the data from the function

                                if(~isempty(option))
                                    %   After processing data save the files to the output directory
                                    outputdirectory = strcat(processeddata, '\Histograms\',datestr(now,30));

                                    %   Makes the directory to put the files in
                                    mkdir(outputdirectory);

                                    %   Goes through the plots and saves them as MATLAB figures also
                                    %   saves the data for each of the plots into a cdf file with a
                                    %   corresponding name

                                    for j = 1:gcf
                                        %   Concatenates strings to point to the correct output
                                        %   path

                                        fileplot = strcat('plot', int2str(j), '.fig');
                                        outputplotpath = strcat(outputdirectory, '\', fileplot);
                                        if(strcmp(option, 'plots') || strcmp(option,'saveall'))
                                            if(valid_range_flag ==2)
                                            saveas(j, outputplotpath);
                                            end
                                        end
                                        filedata = strcat('plot', int2str(j));
                                        outputdatapath = strcat(outputdirectory,'\', filedata);

                                        hFig = get(gcf);
                                        hAxes = hFig.Children;

                                        %   Checks to see if there are multiple plots on the figure
                                        %   if grab the subplot data and store them

                                        if((strcmp(option, 'savedata') || strcmp(option,'saveall')))
                                            if(length(hAxes)>1)
                                            %   Non-efficient
                                               %hLines = [];

                                            %   Preallocate memory for the plots that have subplots
                                                hLines = zeros(1,length(hAxes));
                                                for k = 1:length(hAxes)
                                                    hLines(k) = get(hAxes(length(hAxes) + 1 - k), 'Children');
                                                end
                                                xtmp = cell2mat(get(hLines, 'XData'));
                                                ytmp = cell2mat(get(hLines,'YData'));
                                                cdfwrite(outputdatapath, {'X',xtmp,'Y',ytmp});
                                            %   Else goes and stores the single plot data
                                            else
                                                plottmp = findobj(j, 'Type', 'line');
                                                xtmp = get(plottmp, 'Xdata');
                                                ytmp = get(plottmp, 'Ydata');
                                                cdfwrite(outputdatapath, {'X',xtmp,'Y',ytmp});
                                            end
                                        end
                                    end
                                    %   Clean up plots to speed up later processes
                                    close all
                                end
                            end
                        else

                            cprintf('red','Not valid orbit timespans for orbit: %d.\n', currOrbit);

                        end
                    else

                            cprintf('red','Could not find CDF files for orbit: %d\n', currOrbit)    
                    end

                    if(valid_range_flag == 2)
                        break;
                    end 
                end  

%**************************************************************************
%*************************    NOISEFLOOR    *************************************
%**************************************************************************
       
            case{'noisefloor'}
                for currOrbit=orbitLow:interval:orbitHigh
                %   Change the format of the values and do some string processing.
                %   Unless the naming syntax of the orbit change this part should not be
                %   altered 

                    orbitnum = int2str(currOrbit);

                    %   Gets the string version of an orbit. EX. '05383'
                    while(length(orbitnum) ~= 5)
                    orbitnum = strcat('0', orbitnum);
                    end

                    orbitname = strcat('fa_k0_', orbitnum);

                    %   Inclusion of reading in EES and IES data, the naming syntax was
                    %   originally created by Berkeley, thus it needed to be modified
                    %   to match the existing file names
                    iesorbitname = strcat('fa_k0_ies_',orbitnum,'_v04.cdf');
                    eesorbitname = strcat('fa_k0_ees_',orbitnum,'_v04.cdf');

                %   There is probably a better way than this to error catch if the folder
                %   contains no items

                    directorypath = strcat(fastdata,orbitname, '\');

                    orb_path = strcat(directorypath, orbitname, '_orb.cdf');
                    ef_path = strcat(directorypath, orbitname, '_ef.cdf');
                    db_path = strcat(directorypath, orbitname, '_mag.cdf');
                    sa_path = strcat(directorypath,orbitname, '_sa.cdf');
                    ies_path = strcat(directorypath, iesorbitname);
                    ees_path = strcat(directorypath, eesorbitname);


                    %   Currently the each mode has to do individual tracking because the CDF
                    %   files needed might be different for each mode

                    %   Check for the existence of the cdf files
                    if(exist(orb_path, 'file') == 2 ...
                            && exist(ef_path, 'file') == 2 ...
                            && exist(db_path, 'file') == 2 ...
                            && exist(sa_path, 'file') == 2 ...
                            && exist(ies_path, 'file') == 2 ...
                            && exist(ees_path, 'file') == 2)
                        %   Begin reading the CDFs
                        try
                        orb_data = cdfread(orb_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'FA_POSGEI'},{'FA_VELGEI'},{'FA_POS'},{'FA_VEL'},{'ALT'},{'LAT'},{'LNG'},{'ILAT'},{'MLT'},{'B_MODEL'},{'B_FOOT'},{'FOOT_LAT'},{'FOOT_LNG'}]);
                        if(any(cellfun('isempty',orb_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %orb_data{:,1}  = UNIX time
                        %orb_data{:,2}  = Pos x,y,z(GEI)
                        %orb_data{:,3}  = Vel x,y,z(GEI)
                        %orb_data{:,4}  = Pos x,y,z(GEO)
                        %orb_data{:,5}  = Vel x,y,z(GEO)
                        %orb_data{:,6}  = Altitude (km) 
                        %orb_data{:,7}  = Latitude (deg)
                        %orb_data{:,8}  = Longitude (deg)
                        %orb_data{:,9}  = Invariant Latitude (deg)
                        %orb_data{:,10} = Magnetic Local Time
                        %orb_data{:,11} = B Model x,y,z (GEI)
                        %orb_data{:,12} = B Footprint (mapped to 100 km)
                        %orb_data{:,13} = Latitude Footprint (geodectic)
                        %orb_data{:,14} = Longitude Footpring (geodectic)

                        ef_data = cdfread(ef_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'E_NEAR_B'},{'E_ALONG_V'}]);
                        if(any(cellfun('isempty',ef_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %ef_data{:,1}   = UNIX time
                        %ef_data{:,2}   = E near B (E_z (DCS))
                        %ef_data{:,3}   = E along V (E_x (DCS))

                        mag_data = cdfread(db_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'DB_GEI_O'},{'DB_GEI_E'},{'DB_GEI_B'},{'B_GEI_O'},{'B_GEI_E'},{'B_GEI_B'},{'DB_FAC_V_O'},{'DB_FAC_V_E'},{'DB_FAC_V_B'}]);
                        if(any(cellfun('isempty',mag_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %mag_data{:,1}    = UNIX time
                        %mag_data{:,2:4}  = Delta-B x,y,z (GEI)
                        %mag_data{:,5:7}  = Total B x,y,z (GEI)
                        %mag_data{:,8:10} = Delta-B (FAC_V)

                        sa_data = cdfread(sa_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'}, {'FA_SPIN_RA'}, {'FA_SPIN_DEC'}]);
                        if(any(cellfun('isempty',sa_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %sa_data{:,1}   = UNIX time
                        %sa_data{:,2}   = Right Asenscion Angle (deg)
                        %sa_data{:,3}   = Declination Angle (deg)

                        ees_data = cdfread(ees_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'JEe'}]);
                        if(any(cellfun('isempty',ees_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %ees_data{:,1}   = UNIX time
                        %ees_data{:,2}   = Kinetic Energy Flux(Electron)(W/m^2)                    

                        ies_data = cdfread(ies_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'JEi'}]);
                        if(any(cellfun('isempty',ies_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end                        
                        %ies_data{:,1}   = UNIX time
                        %ies_data{:,2}   = Kinetic Energy Flux(Ion)(W/m^2)  
                        catch exception
                            fprintf([getReport(exception,'basic', 'hyperlinks', 'off') '\n']);
                            cprintf('red', 'Unable to read the right data values from CDF for orbit %d.\n', currOrbit);
                            continue
                        end
                        %   Check if the data is valid -- Has the correct start and end
                        %   times by comparing the UNIX times

                        orb_time = uint32(orb_data{:,1});
                        ef_time = uint32(ef_data{:,1});
                        db_time = uint32(mag_data{:,1});
                        sa_time = uint32(sa_data{:,1});
                        ees_time = uint32(ees_data{:,1});
                        ies_time = uint32(ies_data{:,1});

                        end_times = [orb_time(end), sa_time(end)];
                        start_times = [orb_time(1), sa_time(1)];

                        %   The electric field data must fit within the minimum
                        %   of the end times and the maximum of the start times
                        %   for this to be valid
                        if((db_time(end) >= orb_time(1) ...
                               && db_time(1) <= orb_time(end)) ...
                               && (sa_time(end) >= orb_time(1) ...
                               && sa_time(1) <=orb_time(end)))
                            if((ef_time(1) >= max(start_times) ...
                                    && ef_time(end) <= min(end_times)) ...
                                    && (ees_time(1) >= max(start_times) ...
                                    && ees_time(end) <= min(end_times)) ...
                                    && (ies_time(1) >= max(start_times) ...
                                    && ies_time(end) <= min(end_times)))
                                valid_timespan = true;
                            else
                                valid_timespan = false;
                            end
                        else
                            valid_timespan = false;
                        end

                        if (valid_timespan == true)
                            %   Function calls to be done
                            %   ************************************
                            %   INSERT PROCESSES YOU WANT TO EXECUTE
                            cprintf('comment','Beginning to process orbit: %d\n', currOrbit);

                            %   Begin timer
                            tic;
                            mkdir(orbitbin_directory);
                            efield_singlebin(orb_data,ef_data, sa_data,orbitname,orbitbin_directory);
                            cprintf('comment','Processing for Orbit %d took: %f seconds\n',currOrbit,toc);
                            %   ************************************
                            if(~isempty(option))
                                %   After processing data save the files to the output directory
                                outputdirectory = strcat(orbitbin_directory, orbitname);

                                %   Makes the directory to put the files in
                                mkdir(outputdirectory);

                                %   Goes through the plots and saves them as MATLAB figures also
                                %   saves the data for each of the plots into a cdf file with a
                                %   corresponding name

                                for j = 1:gcf
                                    %   Concatenates strings to point to the correct output
                                    %   path

                                    fileplot = strcat('plot', int2str(j), '.fig');
                                    outputplotpath = strcat(outputdirectory, '\', fileplot);
                                    if(strcmp(option, 'plots') || strcmp(option,'saveall'))
                                        if(valid_range_flag ==2)
                                        saveas(j, outputplotpath);
                                        end
                                    end
                                    filedata = strcat('plot', int2str(j));
                                    outputdatapath = strcat(outputdirectory,'\', filedata);

                                    hFig = get(gcf);
                                    hAxes = hFig.Children;

                                    %   Checks to see if there are multiple plots on the figure
                                    %   if grab the subplot data and store them

                                    if((strcmp(option, 'savedata') || strcmp(option,'saveall')))
                                        if(length(hAxes)>1)
                                        %   Non-efficient
                                           %hLines = [];

                                        %   Preallocate memory for the plots that have subplots
                                            hLines = zeros(1,length(hAxes));
                                            for k = 1:length(hAxes)
                                                hLines(k) = get(hAxes(length(hAxes) + 1 - k), 'Children');
                                            end
                                            xtmp = cell2mat(get(hLines, 'XData'));
                                            ytmp = cell2mat(get(hLines,'YData'));
                                            cdfwrite(outputdatapath, {'X',xtmp,'Y',ytmp});
                                        %   Else goes and stores the single plot data
                                        else
                                            plottmp = findobj(j, 'Type', 'line');
                                            xtmp = get(plottmp, 'Xdata');
                                            ytmp = get(plottmp, 'Ydata');
                                            cdfwrite(outputdatapath, {'X',xtmp,'Y',ytmp});
                                        end
                                    end
                                end
                                %   Clean up plots to speed up later processes
                                close all
                            end
                        else

                            cprintf('red','Not valid orbit timespans for orbit: %d.\n', currOrbit);

                        end
                    else

                            cprintf('red','Could not find CDF files for orbit: %d\n', currOrbit)    
                    end
                    % Clean up if plots are made at all
                    close all
                end
                mkdir(massbin_directory);
                bin_mass(orbitLow, orbitHigh, orbitbin_directory, massbin_directory);
            
%**************************************************************************
%************************** RADAR *****************************************
%**************************************************************************
            case{'radar'}
                for currOrbit=orbitLow:interval:orbitHigh
                %   Change the format of the values and do some string processing.
                %   Unless the naming syntax of the orbit change this part should not be
                %   altered 

                    orbitnum = int2str(currOrbit);

                    %   Gets the string version of an orbit. EX. '05383'
                    while(length(orbitnum) ~= 5)
                    orbitnum = strcat('0', orbitnum);
                    end

                    orbitname = strcat('fa_k0_', orbitnum);

                    %   Inclusion of reading in EES and IES data, the naming syntax was
                    %   originally created by Berkeley, thus it needed to be modified
                    %   to match the existing file names
                    iesorbitname = strcat('fa_k0_ies_',orbitnum,'_v04.cdf');
                    eesorbitname = strcat('fa_k0_ees_',orbitnum,'_v04.cdf');

                %   There is probably a better way than this to error catch if the folder
                %   contains no items

                    directorypath = strcat(fastdata,orbitname, '\');

                    orb_path = strcat(directorypath, orbitname, '_orb.cdf');
                    ef_path = strcat(directorypath, orbitname, '_ef.cdf');
                    db_path = strcat(directorypath, orbitname, '_mag.cdf');
                    sa_path = strcat(directorypath,orbitname, '_sa.cdf');
                    ies_path = strcat(directorypath, iesorbitname);
                    ees_path = strcat(directorypath, eesorbitname);


                    %   Currently the each mode has to do individual tracking because the CDF
                    %   files needed might be different for each mode

                %   Check for the existence of the cdf files
                    if(exist(orb_path, 'file') == 2 ...
                        && exist(ef_path, 'file') == 2 ...
                        && exist(db_path, 'file') == 2 ...
                        && exist(sa_path, 'file') == 2 ...
                        && exist(ies_path, 'file') == 2 ...
                        && exist(ees_path, 'file') == 2)
                        %   Begin reading the CDFs
                        try
                        orb_data = cdfread(orb_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'FA_POSGEI'},{'FA_VELGEI'},{'FA_POS'},{'FA_VEL'},{'ALT'},{'LAT'},{'LNG'},{'ILAT'},{'MLT'},{'B_MODEL'},{'B_FOOT'},{'FOOT_LAT'},{'FOOT_LNG'}]);
                        if(any(cellfun('isempty',orb_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %orb_data{:,1}  = UNIX time
                        %orb_data{:,2}  = Pos x,y,z(GEI)
                        %orb_data{:,3}  = Vel x,y,z(GEI)
                        %orb_data{:,4}  = Pos x,y,z(GEO)
                        %orb_data{:,5}  = Vel x,y,z(GEO)
                        %orb_data{:,6}  = Altitude (km) 
                        %orb_data{:,7}  = Latitude (deg)
                        %orb_data{:,8}  = Longitude (deg)
                        %orb_data{:,9}  = Invariant Latitude (deg)
                        %orb_data{:,10} = Magnetic Local Time
                        %orb_data{:,11} = B Model x,y,z (GEI)
                        %orb_data{:,12} = B Footprint (mapped to 100 km)
                        %orb_data{:,13} = Latitude Footprint (geodectic)
                        %orb_data{:,14} = Longitude Footprint (geodectic)

                        ef_data = cdfread(ef_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'E_NEAR_B'},{'E_ALONG_V'}]);
                        if(any(cellfun('isempty',ef_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %ef_data{:,1}   = UNIX time
                        %ef_data{:,2}   = E near B (E_z (DCS))
                        %ef_data{:,3}   = E along V (E_x (DCS))

                        mag_data = cdfread(db_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'DB_GEI_O'},{'DB_GEI_E'},{'DB_GEI_B'},{'B_GEI_O'},{'B_GEI_E'},{'B_GEI_B'},{'DB_FAC_V_O'},{'DB_FAC_V_E'},{'DB_FAC_V_B'}]);
                        if(any(cellfun('isempty',mag_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %mag_data{:,1}    = UNIX time
                        %mag_data{:,2:4}  = Delta-B x,y,z (GEI)
                        %mag_data{:,5:7}  = Total B x,y,z (GEI)
                        %mag_data{:,8:10} = Delta-B (FAC_V)

                        sa_data = cdfread(sa_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'}, {'FA_SPIN_RA'}, {'FA_SPIN_DEC'}]);
                        if(any(cellfun('isempty',sa_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %sa_data{:,1}   = UNIX time
                        %sa_data{:,2}   = Right Ascenscion Angle (deg)
                        %sa_data{:,3}   = Declination Angle (deg)

                        ees_data = cdfread(ees_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'JEe'}]);
                        if(any(cellfun('isempty',ees_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %ees_data{:,1}   = UNIX time
                        %ees_data{:,2}   = Kinetic Energy Flux(Electron)(W/m^2)                    

                        ies_data = cdfread(ies_path, 'CombineRecords', true, 'Variable', ...
                            [{'TIME'},{'JEi'}]);
                        if(any(cellfun('isempty',ies_data)))
                            cprintf('red', 'Empty set for orb data... Continuing.\n');
                            continue;
                        end
                        %ies_data{:,1}   = UNIX time
                        %ies_data{:,2}   = Kinetic Energy Flux(Ion)(W/m^2)  
                        
                        catch exception
                            fprintf([getReport(exception,'basic', 'hyperlinks', 'off') '\n']);
                            cprintf('red', 'Unable to read the right data values from CDF for orbit %d.\n', currOrbit);
                            continue
                        end

                        orb_time = uint32(orb_data{:,1});
                        ef_time = uint32(ef_data{:,1});
                        db_time = uint32(mag_data{:,1});
                        sa_time = uint32(sa_data{:,1});
                        ees_time = uint32(ees_data{:,1});
                        ies_time = uint32(ies_data{:,1});

                        end_times = [orb_time(end), sa_time(end)];
                        start_times = [orb_time(1), sa_time(1)];

                        %   The electric field data must fit within the minimum
                        %   of the end times and the maximum of the start times
                        %   for this to be valid
                        if((db_time(end) >= orb_time(1) ...
                                && db_time(1) <= orb_time(end)) ...
                                && (sa_time(end) >= orb_time(1) ...
                                && sa_time(1) <=orb_time(end)))
                            if((ef_time(1) >= max(start_times) ...
                                    && ef_time(end) <= min(end_times))  ...
                                    && (ees_time(1) >= max(start_times) ...
                                    && ees_time(end) <= min(end_times)) ...
                                    && (ies_time(1) >= max(start_times) ...
                                    && ies_time(end) <= min(end_times)))
                                valid_timespan = true;
                            else
                                valid_timespan = false;
                            end
                        else
                            valid_timespan = false;
                        end

                        if (valid_timespan == true)
                            %   Function calls to be done
                            %   ************************************
                            %   INSERT PROCESSES YOU WANT TO EXECUTE
                            cprintf('comment','Beginning to process orbit: %d\n', currOrbit);

                            %   Begin timer
                            tic;

                            % Function call for main code processing

                            try
                            ef_radar = radar_locate(orb_data, ef_data);
                            catch exception
                               getReport(exception,'basic', 'hyperlinks', 'off');
                               ef_radar = []; 
                            end
                            
                            if ~isempty(ef_radar)
                                mkdir(radar_directory);
                                save(strcat(radar_directory,orbitname,'_ef_radar'),'ef_radar');
                                cprintf('comment','Valid electric field data saved.\n');
                            end
                            clearvars ef_radar

                            cprintf('comment','Processing for Orbit %d took: %f seconds\n',i,toc);
                            %   ************************************

                        end
                    end
                end
                radar_locate_times(radar_directory);
                
%**************************************************************************
%******************************** POLAR PLOTS *****************************
%**************************************************************************
            
            case{'polarplot'}
                %   Sort by Kp_index and use a binary search algorithm to
                %   find the correct orbit
                
                %   Directory name for where the kp data is stored
                unix_time_matrix = kp_to_unixtime([],kp_index_start, kp_index_end);
                
                %   Now limit the kp range to only values within the
                %   orbit range inputted by the user.
                
                [limited_unix_time_matrix, orbitLow, orbitHigh] = limit_kp(fastdata, orbitLow, orbitHigh, unix_time_matrix);
                
                %orbit_list = zeros(length(limited_unix_time_matrix),1);
                
                %   Decide whether to use binary search algorithm or
                %   sequential search based on how many comparisons are
                %   needed
                
                %   If ceil(log2(orbitHigh - orbitLow)) *
                %   length(limited_unix_time_matrix) > orbitHigh - orbitLow
                %   then execute binary search algorithm
                
                

                    %   Do sequential 
                    orbit_list = sequential_orbit(fastdata, limited_unix_time_matrix, orbitLow, orbitHigh);

          
                
                orbit_list_and_unix_time = [orbit_list limited_unix_time_matrix];
                
                orbit_list_and_unix_time(any(orbit_list_and_unix_time==0,2),:) = [];
                
%                 orbit_list_and_unix_time(any(isnan(orbit_list_and_unix_time),2),:) = [];
                
                            %   Function calls to be done
                            %   ************************************
                            %   INSERT PROCESSES YOU WANT TO EXECUTE
                            cprintf('comment','Beginning to process Polar Plot\n');

                            %   Begin timer
                            tic;
                            %**************************************************
                            %*************INSERT FUNCTION FOR POLAR PLOT*******
                            %**************************************************
                            %Input :
                            %       1. Poynting flux for orbitnum
                            %       2. MLT - mlt_start, mlt_end
                            %       3. MLAT - mlat_start, mlat_end
                            %       4. ALT - alt_start, alt_end
                            %**************************************************
                            interval = 24;
                            polar_plot(orbit_list_and_unix_time, fastdata, processeddata, tmp_directory, mlt_start, mlat_start, alt_start, mlt_end, mlat_end, alt_end, interval);

                            %**************************************************
                            %*************INSERT FUNCTION FOR POLAR PLOT*******
                            %**************************************************
                            cprintf('comment','Processing for Polar Plot: %f seconds\n',toc);
                            %   ************************************
                            if(~isempty(option))
                                %   After processing data save the files to the output directory
                                outputdirectory = strcat(processeddata,'PolarPlots');

                                %   Makes the directory to put the files in
                                mkdir(outputdirectory);

                                %   Goes through the plots and saves them as MATLAB figures also
                                %   saves the data for each of the plots into a cdf file with a
                                %   corresponding name

                                for j = 1:gcf
                                    %   Concatenates strings to point to the correct output
                                    %   path
                                    fileplot = strcat('plot', int2str(j), '.fig');
                                    outputplotpath = strcat(outputdirectory, '\', fileplot);
                                    if(strcmp(option, 'plots'))
                                        saveas(j, outputplotpath);
                                    end
                                end
                            end

               
            end
    diary off
end

